@@ -23,6 +23,7 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.eclipse.swt.widgets.Composite;
 
+import com.clustercontrol.accesscontrol.util.LocalSession;
 import com.clustercontrol.composite.FacilityTreeComposite;
 import com.clustercontrol.repository.util.RepositoryEndpointWrapper;
 import com.clustercontrol.util.FacilityTreeItemUtil;
@@ -56,7 +57,7 @@ public class FacilityTree {
 
 		if (m_facilityTreeCache == null) {
 			// 存在しない場合はキャッシュ再交信再取得
-			refleshCache();
+			refreshCache();
 		}
 		// 要素を取得
 		item = FacilityTreeItemUtil.deepCopy(m_facilityTreeCache, null);
@@ -93,21 +94,22 @@ public class FacilityTree {
 
 	/**
 	 * キャッシュおよび画面のリフレッシュ
+	 * このメソッドはLocalSession以外から呼んではならない！
 	 */
-	public static void reflesh() {
-		//m_log.debug("FacilityTree.reflesh() start");
-
-		refleshCache();
-		refleshComposite();
-
-		//m_log.debug("FacilityTree.reflesh() stop");
+	public static void refresh() {
+		m_log.trace("FacilityTree.refresh() start");
+		
+		refreshCache();
+		refreshComposite();
+		
+		m_log.trace("FacilityTree.refresh() stop");
 	}
 
 	/**
 	 * キャッシュのリフレッシュ
 	 */
-	public static void refleshCache() {
-		//m_log.debug("FacilityTree.refleshCache() : start");
+	private static void refreshCache() {
+		//m_log.debug("FacilityTree.getFacilityTree() : start");
 
 		// 先にキャッシュクリア
 		// clearCache() ;
@@ -115,41 +117,41 @@ public class FacilityTree {
 		// 再登録
 		FacilityTreeItem item = null;
 		try {
-			item = RepositoryEndpointWrapper.getFacilityTree();
+			item = RepositoryEndpointWrapper.getFacilityTree(null);
 
 			if (item != null) {
 				m_facilityTreeCache = item;
 			}
 
 		} catch (Exception e) {
-			m_log.warn("refleshCache(), " + e.getMessage(), e);
+			m_log.warn("getFacilityTree(), " + e.getMessage(), e);
 			return;
 		}
 
-		//m_log.debug("FacilityTree.refleshCache() : stop");
+		m_log.trace("FacilityTree.refreshCache() : stop");
 	}
 
 	/**
 	 * ファシリティツリー画面を再描画する
 	 */
-	public static void refleshComposite() {
-		//m_log.debug("FacilityTree.refleshComposite() : start");
+	public static void refreshComposite() {
+		m_log.trace("FacilityTree.refreshComposite() : start");
 
 		synchronized (m_DisplayViewSet) {
 
 			Iterator<Composite> iterator = m_DisplayViewSet.iterator();
 			while (iterator.hasNext()) {
 				FacilityTreeComposite composite = (FacilityTreeComposite) iterator
-				.next();
+						.next();
 				if (!composite.isDisposed()) {
-					//m_log.debug("FacilityTree.refleshComposite() : target is "
-					//+ composite.getClass().getCanonicalName());
+					m_log.trace("FacilityTree.refreshComposite() : target is "
+					+ composite.getClass().getCanonicalName());
 					composite.update();
 				}
 			}
 		}
 
-		//m_log.debug("refleshComposite() : stop");
+		m_log.trace("refreshComposite() : stop");
 	}
 
 	/**
