@@ -19,9 +19,9 @@ import org.eclipse.jface.action.Action;
 import org.eclipse.jface.viewers.StructuredSelection;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.bean.PropertyConstant;
-import com.clustercontrol.composite.PropertySheet;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.PropertySheet;
 
 /**
  * プロパティを削除するクライアント側アクションクラス<BR>
@@ -55,10 +55,10 @@ public class DeletePropertyAction extends Action {
 	public void run() {
 		//選択されたプロパティを取得
 		StructuredSelection selection = (StructuredSelection) m_viewer
-		.getSelection();
+				.getSelection();
 		Property property = (Property) selection.getFirstElement();
 
-		if (property.getCopy() == PropertyConstant.COPY_OK) {
+		if (property.getCopy() == PropertyDefineConstant.COPY_OK) {
 			//選択されたプロパティを削除
 			property.getParent().removeChildren(property);
 		}
