@@ -24,9 +24,9 @@ import com.clustercontrol.bean.TableColumnInfo;
 import com.clustercontrol.util.Messages;
 
 /**
- * アクセス[ユーザ]ビューのテーブル定義を取得するクライアント側アクションクラス<BR>
+ * アカウント[ユーザ]ビューのテーブル定義を取得するクライアント側アクションクラス<BR>
  * 
- * アクセス管理のビュー[ユーザ]のカラムの情報を取得します。
+ * アカウントのビュー[ユーザ]のカラムの情報を取得します。
  * Hinemosではロケールによって動作を変えるために定義情報も
  * マネージャから取得します。
  * 
@@ -38,7 +38,7 @@ public class GetUserListTableDefine {
 	/** ユーザID */
 	public static final int UID = 0;
 
-	/** 名前 */
+	/** ユーザ名 */
 	public static final int NAME = 1;
 
 	/** 説明 */
@@ -76,7 +76,7 @@ public class GetUserListTableDefine {
 
 		/** メイン処理 */
 		tableDefine.add(UID, new TableColumnInfo( Messages.getString("user.id", locale), TableColumnInfo.NONE, 100, SWT.LEFT) );
-		tableDefine.add(NAME, new TableColumnInfo( Messages.getString("name", locale), TableColumnInfo.NONE, 150, SWT.LEFT) );
+		tableDefine.add(NAME, new TableColumnInfo( Messages.getString("user.name", locale), TableColumnInfo.NONE, 150, SWT.LEFT) );
 		tableDefine.add(DESCRIPTION, new TableColumnInfo( Messages.getString("description", locale), TableColumnInfo.NONE, 200, SWT.LEFT) );
 		tableDefine.add(CREATOR_NAME, new TableColumnInfo( Messages.getString("creator.name", locale), TableColumnInfo.NONE, 100, SWT.LEFT) );
 		tableDefine.add(CREATE_TIME, new TableColumnInfo( Messages.getString("create.time", locale), TableColumnInfo.NONE, 140, SWT.LEFT) );
