@@ -17,16 +17,18 @@ package com.clustercontrol.calendar.composite.action;
 
 import java.util.ArrayList;
 
+import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.viewers.DoubleClickEvent;
 import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.StructuredSelection;
 
 import com.clustercontrol.accesscontrol.action.CheckPermission;
-import com.clustercontrol.bean.PropertyConstant;
+import com.clustercontrol.accesscontrol.bean.FunctionConstant;
+import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.SystemPrivilegeMode;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.calendar.action.GetCalendarListTableDefine;
 import com.clustercontrol.calendar.composite.CalendarListComposite;
 import com.clustercontrol.calendar.dialog.CalendarDialog;
-import com.clustercontrol.calendar.view.CalendarListView;
 
 /**
  * カレンダ[一覧]ビュー用のテーブルビューア用のDoubleClickListenerクラスです。
@@ -36,19 +38,15 @@ import com.clustercontrol.calendar.view.CalendarListView;
  */
 public class CalendarDoubleClickListener implements IDoubleClickListener {
 	/** カレンダ[一覧]ビュー用のコンポジット */
-	protected CalendarListComposite m_composite;
+	private CalendarListComposite m_composite;
 
-	/** 呼び出し元ビュー */
-	private CalendarListView view = null;
-	
 	/**
 	 * コンストラクタ
 	 * 
 	 * @param composite カレンダ[一覧]ビュー用のコンポジット
 	 */
-	public CalendarDoubleClickListener(CalendarListComposite composite, CalendarListView view) {
+	public CalendarDoubleClickListener(CalendarListComposite composite) {
 		m_composite = composite;
-		this.view = view;
 	}
 
 	/**
@@ -78,19 +76,21 @@ public class CalendarDoubleClickListener implements IDoubleClickListener {
 
 		if(calendarId != null){
 			// 現在のユーザがカレンダ機能の設定権限をもつか否かを取得する
-			boolean permission = new CheckPermission().check("CalendarWrite");
+			boolean permission = new CheckPermission().check(FunctionConstant.CALENDAR, SystemPrivilegeMode.WRITE);
 
 			// ダイアログを生成
 			CalendarDialog dialog = null;
 
 			if(permission){
-				dialog = new CalendarDialog(m_composite.getShell(), calendarId, PropertyConstant.MODE_MODIFY, view);
+				dialog = new CalendarDialog(m_composite.getShell(), calendarId, PropertyDefineConstant.MODE_MODIFY);
 			}else{
-				dialog = new CalendarDialog(m_composite.getShell(), calendarId, PropertyConstant.MODE_SHOW, view);
+				dialog = new CalendarDialog(m_composite.getShell(), calendarId, PropertyDefineConstant.MODE_SHOW);
 			}
 
 			// ダイアログにて変更が選択された場合、入力内容をもって登録を行う。
-			dialog.open();
+			if (dialog.open() == IDialogConstants.OK_ID) {
+				m_composite.update();
+			}
 		}
 	}
 
