@@ -37,8 +37,8 @@ import com.clustercontrol.collectiverun.action.ModifyMaster;
 import com.clustercontrol.collectiverun.bean.CommandTypeConstant;
 import com.clustercontrol.collectiverun.composite.action.MasterInfoModifyListener;
 import com.clustercontrol.collectiverun.util.TreeItemUtil;
-import com.clustercontrol.composite.NumberVerifyListener;
-import com.clustercontrol.composite.StringVerifyListener;
+import com.clustercontrol.composite.action.NumberVerifyListener;
+import com.clustercontrol.composite.action.StringVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.collectiverun.CommandInfo;
@@ -645,7 +645,7 @@ public class CommandComposite extends Composite {
 	 * @param result
 	 *            ValidateResultオブジェクト
 	 */
-	protected void displayError(ValidateResult result) {
+	private void displayError(ValidateResult result) {
 		MessageDialog.openWarning(
 				null,
 				result.getID(),
