@@ -37,8 +37,8 @@ import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.collectiverun.util.CollectiveRunEndpointWrapper;
 import com.clustercontrol.collectiverun.util.ParameterPropertyUtil;
-import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.viewer.PropertySheet;
 import com.clustercontrol.ws.collectiverun.HashMapInfo;
 import com.clustercontrol.ws.collectiverun.HashMapInfo.Map1;
 import com.clustercontrol.ws.collectiverun.InvalidRole_Exception;
@@ -56,16 +56,16 @@ public class ParameterViewComposite extends Composite {
 	private static Log m_log = LogFactory.getLog( ParameterViewComposite.class );
 
 	/** プロパティシート */
-	protected PropertySheet propertySheet = null;
+	private PropertySheet propertySheet = null;
 
 	/** コンボボックス */
-	protected Combo type = null;
+	private Combo type = null;
 
 	/** 種別ハッシュマップ */
-	protected HashMapInfo typeMap = null;
+	private HashMapInfo typeMap = null;
 
 	/** 種別文字列 */
-	protected List<String> typeList = null;
+	private List<String> typeList = null;
 
 	private boolean openAccessInformation = false;
 
