@@ -31,7 +31,7 @@ import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.collectiverun.action.ModifyMaster;
 import com.clustercontrol.collectiverun.composite.action.MasterInfoModifyListener;
 import com.clustercontrol.collectiverun.util.TreeItemUtil;
-import com.clustercontrol.composite.StringVerifyListener;
+import com.clustercontrol.composite.action.StringVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.collectiverun.ItemInfo;
@@ -287,7 +287,7 @@ public class TypeComposite extends Composite {
 	 * @param result
 	 *            ValidateResultオブジェクト
 	 */
-	protected void displayError(ValidateResult result) {
+	private void displayError(ValidateResult result) {
 		MessageDialog.openWarning(
 				null,
 				result.getID(),
