@@ -60,11 +60,15 @@ public class AgentCreateDialog extends CommonMonitorTruthDialog {
 	 *            親のシェルオブジェクト
 	 * @param monitorId
 	 *            変更する監視項目ID
+	 * @param updateFlg
+	 *            更新するか否か（true:変更、false:新規登録）
+	 * 
 	 */
-	public AgentCreateDialog(Shell parent, String monitorId) {
+	public AgentCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
 		super(parent);
 
 		this.monitorId = monitorId;
+		this.updateFlg = updateFlg;
 	}
 
 	// ----- instance メソッド ----- //
@@ -187,7 +191,7 @@ public class AgentCreateDialog extends CommonMonitorTruthDialog {
 		MonitorInfo info = this.inputData;
 		if(info != null){
 			String[] args = { info.getMonitorId() };
-			if(this.monitorId == null){
+			if(!this.updateFlg){
 				// 作成の場合
 				try {
 					result = MonitorSettingEndpointWrapper.addMonitor(info);
