@@ -15,13 +15,12 @@
 
 package com.clustercontrol.http.factory;
 
-import javax.ejb.CreateException;
-import javax.naming.NamingException;
-
-import com.clustercontrol.commons.scheduler.TriggerScheduler;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.http.util.ControlHttpInfo;
 import com.clustercontrol.monitor.run.factory.AddMonitor;
 import com.clustercontrol.monitor.run.factory.AddMonitorNumericValueType;
+import com.clustercontrol.plugin.impl.SchedulerPlugin.TriggerType;
 
 /**
  * HTTP監視 数値監視用をマネージャに登録するクラス<BR>
@@ -35,7 +34,7 @@ public class AddMonitorHttp extends AddMonitorNumericValueType{
 	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#addCheckInfo()
 	 */
 	@Override
-	protected boolean addCheckInfo() throws CreateException, NamingException{
+	protected boolean addCheckInfo() throws MonitorNotFound, InvalidRole {
 
 		// HTTP監視情報を追加
 		ControlHttpInfo http = new ControlHttpInfo(m_monitorInfo.getMonitorId(), m_monitorInfo.getMonitorTypeId());
@@ -54,7 +53,7 @@ public class AddMonitorHttp extends AddMonitorNumericValueType{
 	 * スケジュール実行種別を返します。
 	 */
 	@Override
-	protected String getTriggerType() {
-		return TriggerScheduler.TRIGGER_TYPE_SIMPLE;
+	protected TriggerType getTriggerType() {
+		return TriggerType.SIMPLE;
 	}
 }
