@@ -34,6 +34,7 @@ import com.clustercontrol.jobmanagement.action.GetJobDetailTableDefine;
 import com.clustercontrol.jobmanagement.composite.action.JobDetailSelectionChangedListener;
 import com.clustercontrol.jobmanagement.composite.action.SessionJobDoubleClickListener;
 import com.clustercontrol.jobmanagement.util.JobEndpointWrapper;
+import com.clustercontrol.jobmanagement.viewer.JobTableTreeViewer;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 import com.clustercontrol.ws.jobmanagement.JobInfo;
@@ -51,15 +52,15 @@ public class DetailComposite extends Composite {
 	private static Log m_log = LogFactory.getLog( DetailComposite.class );
 
 	/** テーブルビューアー */
-	protected JobTableTreeViewer m_viewer = null;
+	private JobTableTreeViewer m_viewer = null;
 	/** セッションID */
-	protected String m_sessionId = null;
+	private String m_sessionId = null;
 	/** 所属ジョブユニットのジョブID */
-	protected String m_jobunitId = null;
+	private String m_jobunitId = null;
 	/** ジョブID */
-	protected String m_jobId = null;
+	private String m_jobId = null;
 	/** セッションID用ラベル */
-	protected Label m_sessionIdLabel = null;
+	private Label m_sessionIdLabel = null;
 
 	/**
 	 * コンストラクタ
