@@ -31,14 +31,14 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.jobmanagement.action.GetHistoryFilterProperty;
 import com.clustercontrol.jobmanagement.bean.HistoryFilterPropertyConstant;
-import com.clustercontrol.jobmanagement.composite.JobPropertyDefine;
+import com.clustercontrol.jobmanagement.editor.JobPropertyDefine;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 
 /**
  * ジョブ[履歴フィルタ処理]のダイアログクラスです。
@@ -129,11 +129,12 @@ public class HistoryFilterDialog extends CommonDialog {
 		if(filterProperty == null){
 			filterProperty = new GetHistoryFilterProperty().getProperty();
 		}
-		ArrayList jobId = PropertyUtil.getProperty(filterProperty,
+		ArrayList<Property> jobId = PropertyUtil.getProperty(filterProperty,
 				HistoryFilterPropertyConstant.JOB_ID);
 		JobPropertyDefine define = new JobPropertyDefine();
-		((Property) jobId.get(0)).setDefine(define);
+		jobId.get(0).setDefine(define);
 		this.propertySheet.setInput(filterProperty);
+		this.propertySheet.expandAll();
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
@@ -203,7 +204,7 @@ public class HistoryFilterDialog extends CommonDialog {
 					public void widgetSelected(SelectionEvent e) {
 						// プロパティ設定
 						filterProperty = new GetHistoryFilterProperty().getProperty();
-						ArrayList jobId = PropertyUtil.getProperty(filterProperty,
+						ArrayList<Property> jobId = PropertyUtil.getProperty(filterProperty,
 								HistoryFilterPropertyConstant.JOB_ID);
 						JobPropertyDefine define = new JobPropertyDefine();
 						((Property) jobId.get(0)).setDefine(define);
