@@ -25,13 +25,16 @@ import javax.persistence.EntityManager;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.commons.scheduler.QuartzUtil;
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidSetting;
 import com.clustercontrol.fault.JobInfoNotFound;
 import com.clustercontrol.fault.JobKickDuplicate;
+import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
 import com.clustercontrol.jobmanagement.bean.JobFileCheck;
 import com.clustercontrol.jobmanagement.bean.JobTriggerInfo;
 import com.clustercontrol.jobmanagement.bean.JobTriggerTypeConstant;
@@ -230,7 +233,7 @@ public class ModifyJobKick {
 	 * @throws HinemosUnknown
 	 * @throws JobInfoNotFound
 	 */
-	public void modifySchedule(JobSchedule info, String loginUser) throws HinemosUnknown, JobInfoNotFound{
+	public void modifySchedule(JobSchedule info, String loginUser) throws HinemosUnknown, JobInfoNotFound, ObjectPrivilege_InvalidRole{
 		m_log.debug("modifySchedule() : id=" + info.getId() + ", jobId=" + info.getJobId());
 		JpaTransactionManager jtm = new JpaTransactionManager();
 		EntityManager em = jtm.getEntityManager();
@@ -238,7 +241,8 @@ public class ModifyJobKick {
 		Timestamp now = new Timestamp(new Date().getTime());
 		// DBにスケジュール情報を保存
 		try {
-			JobScheduleEntity bean  = em.find(JobScheduleEntity.class, info.getId());
+			JobScheduleEntity bean  = ((HinemosEntityManager)em).find(JobScheduleEntity.class, info.getId(), 
+					ObjectPrivilegeMode.WRITE);
 			if (bean == null) {
 				JobInfoNotFound e = new JobInfoNotFound("JobScheduleEntity.findByPrimaryKey");
 				m_log.info(e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -271,6 +275,8 @@ public class ModifyJobKick {
 			bean.setUpdateUser(loginUser);
 		} catch (JobInfoNotFound e) {
 			throw e;
+		} catch (ObjectPrivilege_InvalidRole e) {
+			throw e;
 		} catch (Exception e) {
 			m_log.warn("modifySchedule() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
@@ -321,7 +327,7 @@ public class ModifyJobKick {
 	 * @throws HinemosUnknown
 	 * @throws JobInfoNotFound
 	 */
-	public void modifyFileCheck(JobFileCheck info, String loginUser) throws HinemosUnknown, JobInfoNotFound{
+	public void modifyFileCheck(JobFileCheck info, String loginUser) throws HinemosUnknown, JobInfoNotFound, ObjectPrivilege_InvalidRole{
 		m_log.debug("modifyFileCheck() : scheduleId=" + info.getId());
 		JpaTransactionManager jtm = new JpaTransactionManager();
 		EntityManager em = jtm.getEntityManager();
@@ -329,7 +335,8 @@ public class ModifyJobKick {
 		Timestamp now = new Timestamp(new Date().getTime());
 		// DBにファイルチェック情報を保存
 		try {
-			JobFileCheckEntity bean  = em.find(JobFileCheckEntity.class, info.getId());
+			JobFileCheckEntity bean  = ((HinemosEntityManager)em).find(JobFileCheckEntity.class, info.getId(), 
+					ObjectPrivilegeMode.WRITE);
 			if (bean == null) {
 				JobInfoNotFound e = new JobInfoNotFound("JobFileCheckEntity.findByPrimaryKey");
 				m_log.info(e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -361,6 +368,8 @@ public class ModifyJobKick {
 			bean.setUpdateUser(loginUser);
 		} catch (JobInfoNotFound e) {
 			throw e;
+		} catch (ObjectPrivilege_InvalidRole e) {
+			throw e;
 		} catch (Exception e) {
 			m_log.warn("modifyFileCheck() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
@@ -401,7 +410,7 @@ public class ModifyJobKick {
 	 * @see com.clustercontrol.jobmanagement.util.QuartzUtil#getQuartzManager()
 	 * @see com.clustercontrol.quartzmanager.ejb.session.QuartzManager#deleteSchedule(java.lang.String, java.lang.String)
 	 */
-	public void deleteSchedule(String scheduleId) throws HinemosUnknown, JobInfoNotFound {
+	public void deleteSchedule(String scheduleId) throws HinemosUnknown, JobInfoNotFound, ObjectPrivilege_InvalidRole {
 		// スケジュール定義を削除
 		m_log.debug("deleteSchedule() : id=" + scheduleId);
 
@@ -410,7 +419,8 @@ public class ModifyJobKick {
 		// DBのスケジュール情報を削除
 		try {
 			//削除対象を検索
-			JobScheduleEntity jobScheduleEntity = em.find(JobScheduleEntity.class, scheduleId);
+			JobScheduleEntity jobScheduleEntity = ((HinemosEntityManager)em).find(JobScheduleEntity.class, scheduleId, 
+					ObjectPrivilegeMode.WRITE);
 			if (jobScheduleEntity == null) {
 				JobInfoNotFound e = new JobInfoNotFound("JobScheduleEntity.findByPrimaryKey");
 				m_log.info(e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -420,6 +430,8 @@ public class ModifyJobKick {
 			em.remove(jobScheduleEntity);
 		} catch (JobInfoNotFound e) {
 			throw e;
+		} catch (ObjectPrivilege_InvalidRole e) {
+			throw e;
 		} catch (Exception e) {
 			m_log.warn("deleteSchedule() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
@@ -428,7 +440,7 @@ public class ModifyJobKick {
 		//CronTriggerを削除
 		SchedulerPlugin.deleteJob(SchedulerType.DBMS, scheduleId, QuartzConstant.GROUP_NAME);
 	}
-	public void deleteFileCheck(String scheduleId) throws HinemosUnknown, JobInfoNotFound {
+	public void deleteFileCheck(String scheduleId) throws HinemosUnknown, JobInfoNotFound, ObjectPrivilege_InvalidRole {
 		// ファイルチェック定義を削除
 		m_log.debug("deleteFileCheck() : id=" + scheduleId);
 		JpaTransactionManager jtm = null;
@@ -439,7 +451,8 @@ public class ModifyJobKick {
 		// DBのファイルチェック情報を削除
 		try {
 			//削除対象を検索
-			JobFileCheckEntity jobFileCheckEntity = em.find(JobFileCheckEntity.class, scheduleId);
+			JobFileCheckEntity jobFileCheckEntity = ((HinemosEntityManager)em).find(JobFileCheckEntity.class, scheduleId,
+					ObjectPrivilegeMode.WRITE);
 			if (jobFileCheckEntity == null) {
 				JobInfoNotFound e = new JobInfoNotFound("JobFileCheckEntity.findByPrimaryKey");
 				m_log.info(e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -449,6 +462,8 @@ public class ModifyJobKick {
 			em.remove(jobFileCheckEntity);
 		} catch (JobInfoNotFound e) {
 			throw e;
+		} catch (ObjectPrivilege_InvalidRole e) {
+			throw e;
 		} catch (Exception e) {
 			m_log.warn("deleteFileCheck() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
