@@ -578,6 +578,32 @@ public class JobUtil {
 		if (item.getData().getType() == JobConstant.TYPE_REFERJOB) {
 			item.getData().setReferJobUnitId(jobunitId);
 		}
+		
+		// 通知グループIDを新しいジョブユニットIDのものに変更する
+		List<JobNotificationsInfo> jobNotifyList = item.getData().getNotifications();
+		Iterator<JobNotificationsInfo> itrJob = jobNotifyList.iterator();
+
+		// 新しい通知グループIDを作成
+		String newNotifyGroupId = NotifyGroupIdGenerator.createNotifyGroupIdJob(jobunitId, item.getData().getId(), 0);
+		m_log.debug("changeJobId() newNotifyGroupId = " + newNotifyGroupId);
+		// ジョブの通知の種類（開始・通知・警告・危険）分調べる
+		while(itrJob.hasNext()){
+			JobNotificationsInfo jobNotify = itrJob.next();
+			jobNotify.setNotifyGroupId(newNotifyGroupId);
+
+			// 通知関連情報を調査
+			List<NotifyRelationInfo> ctNotify = jobNotify.getNotifyId();
+
+			if(ctNotify != null) {
+				Iterator<NotifyRelationInfo> itrNotify = ctNotify.iterator();
+
+				// 通知関連情報内の通知グループIDの変更
+				while(itrNotify.hasNext()){
+					NotifyRelationInfo notify = itrNotify.next();
+					notify.setNotifyGroupId(newNotifyGroupId);
+				}
+			}
+		}
 
 		// 子のジョブツリーアイテムを再帰的に呼び出す
 		for (JobTreeItem child : item.getChildren()) {
