@@ -94,7 +94,7 @@ public class MaintenanceDisableAction implements IViewActionDelegate {
 			return;
 		}
 
-		boolean hasRole = true; //設定権限を持っているかどうか
+		boolean hasRole = true;
 		// 実行
 		for(Object o : objs){
 			maintenanceId = (String) ((ArrayList)o).get(GetMaintenanceListTableDefine.MAINTENANCE_ID);
@@ -102,16 +102,16 @@ public class MaintenanceDisableAction implements IViewActionDelegate {
 			try{
 				MaintenanceEndpointWrapper.setMaintenanceStatus(maintenanceId, false);
 				successList.append(maintenanceId + "\n");
-			}catch (InvalidRole_Exception e) {
+			} catch (InvalidRole_Exception e) {
 				failureList.append(maintenanceId + "\n");
-				m_log.warn("run() setMaintenanceStatus maintenanceId=" + maintenanceId + ", " + e.getMessage(), e);
+				m_log.warn("run() setNotifyStatus targetId=" + maintenanceId + ", " + e.getMessage(), e);
 				hasRole = false;
 			}catch (Exception e) {
 				failureList.append(maintenanceId + "\n");
 				m_log.warn("run() setMaintenanceStatus maintenanceId=" + maintenanceId + ", " + e.getMessage(), e);
 			}
 		}
-		
+
 		if (!hasRole) {
 			// 権限がない場合にはエラーメッセージを表示する
 			MessageDialog.openInformation(null, Messages.getString("message"),
