@@ -135,7 +135,7 @@ public class StringValueInfoComposite extends Composite {
 		gridData.verticalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.grabExcessVerticalSpace = true;
-		gridData.horizontalSpan = 13;
+		gridData.horizontalSpan = 12;
 		this.m_infoList.setLayoutData(gridData);
 
 		/*
@@ -150,7 +150,7 @@ public class StringValueInfoComposite extends Composite {
 		gridData.verticalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.grabExcessVerticalSpace = true;
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = 3;
 		composite.setLayoutData(gridData);
 
 		// 追加ボタン
@@ -328,7 +328,7 @@ public class StringValueInfoComposite extends Composite {
 	 * @param label ボタンに表示するテキスト
 	 * @return ボタン
 	 */
-	protected Button createButton(Composite parent, String label) {
+	private Button createButton(Composite parent, String label) {
 		Button button = new Button(parent, SWT.NONE);
 
 		GridData gridData = new GridData();
@@ -346,7 +346,7 @@ public class StringValueInfoComposite extends Composite {
 	 * 
 	 * @return 識別キー。選択されていない場合は、<code>null</code>。
 	 */
-	protected String getSelectIdentifier() {
+	private String getSelectIdentifier() {
 		StructuredSelection selection = (StructuredSelection) this.m_infoList.getTableViewer().getSelection();
 
 		if (selection.getFirstElement() instanceof MonitorStringValueInfo) {
@@ -363,7 +363,7 @@ public class StringValueInfoComposite extends Composite {
 	 * 
 	 * @param identifier 識別キー
 	 */
-	protected void selectItem(String identifier) {
+	private void selectItem(String identifier) {
 		Table table = this.m_infoList.getTableViewer().getTable();
 		TableItem[] items = table.getItems();
 
