@@ -42,10 +42,10 @@ import com.clustercontrol.ws.monitor.MonitorInfo;
  */
 public class CommonMonitorNumericDialog extends CommonMonitorDialog {
 
-	protected Group groupCollect = null;			// 収集グループ
+	private Group groupCollect = null;			// 収集グループ
 
 	/** 収集を有効にする */
-	protected Button confirmCollectValid = null;
+	private Button confirmCollectValid = null;
 
 	/** 収集値表示名 */
 	protected Text itemName = null;
@@ -77,27 +77,6 @@ public class CommonMonitorNumericDialog extends CommonMonitorDialog {
 		super(parent);
 	}
 
-	/**
-	 * 作成用ダイアログのインスタンスを返します。
-	 * 
-	 * @param parent 親のシェルオブジェクト
-	 * @param monitorType 監視判定タイプ
-	 */
-	public CommonMonitorNumericDialog(Shell parent, int monitorType) {
-		super(parent, monitorType);
-	}
-
-	/**
-	 * 変更用ダイアログのインスタンスを返します。
-	 * 
-	 * @param parent 親のシェルオブジェクト
-	 * @param monitorId 変更する監視項目ID
-	 * @param monitorType 監視判定タイプ
-	 */
-	public CommonMonitorNumericDialog(Shell parent, String monitorId, int monitorType) {
-		super(parent, monitorId, monitorType);
-	}
-
 	// ----- instance メソッド ----- //
 
 	/**
@@ -235,7 +214,7 @@ public class CommonMonitorNumericDialog extends CommonMonitorDialog {
 	 * 収集エリアを有効/無効化します。
 	 * 
 	 */
-	protected void setCollectorEnabled(boolean enabled){
+	private void setCollectorEnabled(boolean enabled){
 		itemName.setEnabled(enabled);
 		measure.setEnabled(enabled);
 
