@@ -95,7 +95,7 @@ public class StatusView extends ScopeListBaseView {
 
 		// 設定情報反映
 		IPreferenceStore store = ClusterControlPlugin.getDefault()
-		.getPreferenceStore();
+				.getPreferenceStore();
 
 		this.setInterval(store
 				.getInt(MonitorPreferencePage.P_STATUS_UPDATE_CYCLE));
@@ -126,7 +126,7 @@ public class StatusView extends ScopeListBaseView {
 	/**
 	 * ポップアップメニューを作成します。
 	 */
-	protected void createContextMenu() {
+	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
 		menuManager.addMenuListener(new IMenuListener() {
@@ -151,12 +151,12 @@ public class StatusView extends ScopeListBaseView {
 	 * 
 	 * @param manager ポップアップメニューオブジェクト
 	 */
-	protected void fillContextMenu(IMenuManager manager) {
+	private void fillContextMenu(IMenuManager manager) {
 		//ビューのアクションのインスタンスを取得
 		IToolBarManager toolbar = this.getViewSite().getActionBars()
-		.getToolBarManager();
+				.getToolBarManager();
 		ActionContributionItem deleteAction = (ActionContributionItem) toolbar
-		.find(StatusDeleteAction.ID);
+				.find(StatusDeleteAction.ID);
 
 		//ポップアップメニューにアクションを追加
 		manager.add(deleteAction.getAction());
