@@ -89,7 +89,11 @@ public class CollectorEnableAction implements IViewActionDelegate {
 
 			targetIdList.put(monitorId, monitorTypeId);
 
-			targetList.append(monitorId + "\n");
+			if (targetList.length() > 0) {
+				targetList.append(", ");
+				
+			}
+			targetList.append(monitorId);
 		}
 
 		// 実行確認(NG→終了)
@@ -100,7 +104,7 @@ public class CollectorEnableAction implements IViewActionDelegate {
 				Messages.getString("message.monitor.71", args))) {
 			return;
 		}
-		
+
 		boolean hasRole = true; //設定権限を持っているかどうか
 		// 実行
 		for(String targetId : targetIdList.keySet()){
@@ -110,17 +114,26 @@ public class CollectorEnableAction implements IViewActionDelegate {
 
 			try{
 				MonitorSettingEndpointWrapper.setStatusCollector(monitorId, monitorTypeId, true);
-				successList.append(targetId + "\n");
-			}catch (InvalidRole_Exception e) {
-				failureList.append(targetId + "\n");
-				m_log.warn("run() setStatusCollector monitorId=" + monitorId + ", " + e.getMessage(), e);
+				if (successList.length() > 0) {
+					successList.append(", ");
+				}
+				successList.append(targetId);
+			} catch (InvalidRole_Exception e) {
+				if (failureList.length() > 0) {
+					failureList.append(", ");
+				}
+				failureList.append(targetId + "(" + e.getMessage() + ")");
+				m_log.warn("run() setStatusCollector monitorId=" + monitorId + ", " + e.getMessage());
 				hasRole = false;
 			}catch (Exception e) {
-				failureList.append(targetId + "\n");
-				m_log.warn("run() setStatusCollector monitorId=" + monitorId + ", " + e.getMessage(), e);
+				if (failureList.length() > 0) {
+					failureList.append(", ");
+				}
+				failureList.append(targetId + "(" + e.getMessage() + ")");
+				m_log.warn("run() setStatusCollector monitorId=" + monitorId + ", " + e.getMessage());
 			}
 		}
-		
+
 		if (!hasRole) {
 			// 権限がない場合にはエラーメッセージを表示する
 			MessageDialog.openInformation(null, Messages.getString("message"),
