@@ -37,17 +37,20 @@ public class GetMailTemplateListTableDefine {
 	/** 説明。 */
 	public static final int DESCRIPTION = 1;
 
+	/** オーナーロール */
+	public static final int OWNER_ROLE = 2;
+
 	/** 新規作成ユーザ。 */
-	public static final int CREATE_USER = 2;
+	public static final int CREATE_USER = 3;
 
 	/** 作成日時。 */
-	public static final int CREATE_TIME = 3;
+	public static final int CREATE_TIME = 4;
 
 	/** 最終変更ユーザ。 */
-	public static final int UPDATE_USER = 4;
+	public static final int UPDATE_USER = 5;
 
 	/** 最終変更日時。 */
-	public static final int UPDATE_TIME = 5;
+	public static final int UPDATE_TIME = 6;
 
 	/** 初期表示時ソートカラム。 */
 	public static final int SORT_COLUMN_INDEX = MAIL_TEMPLATE_ID;
@@ -76,6 +79,9 @@ public class GetMailTemplateListTableDefine {
 		tableDefine.add(DESCRIPTION,
 				new TableColumnInfo(Messages.getString("description", locale), TableColumnInfo.NONE, 250, SWT.LEFT));
 
+		tableDefine.add(OWNER_ROLE,
+				new TableColumnInfo(Messages.getString("owner.role.id", locale), TableColumnInfo.NONE, 130, SWT.LEFT));
+
 		tableDefine.add(CREATE_USER,
 				new TableColumnInfo(Messages.getString("creator.name", locale), TableColumnInfo.NONE, 130, SWT.LEFT));
 
