@@ -27,6 +27,8 @@ import java.util.Properties;
 import java.util.StringTokenizer;
 import java.util.Vector;
 
+import javax.activation.DataHandler;
+import javax.activation.FileDataSource;
 import javax.mail.AuthenticationFailedException;
 import javax.mail.Message;
 import javax.mail.MessagingException;
@@ -34,12 +36,15 @@ import javax.mail.Session;
 import javax.mail.Transport;
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
+import javax.mail.internet.MimeBodyPart;
 import javax.mail.internet.MimeMessage;
+import javax.mail.internet.MimeMultipart;
 import javax.mail.internet.MimeUtility;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.notify.bean.NotifyRequestMessage;
 import com.clustercontrol.notify.bean.OutputBasicInfo;
@@ -197,7 +202,12 @@ public class SendMail implements Notifier {
 			}
 
 			try {
-				this.sendMail(addresses, subject, content);
+				if(outputInfo.getPluginId().equals(HinemosModuleConstant.REPORTING) && outputInfo.getSubKey() != null) {
+					// レポーティングオプション用添付ファイル対応
+					this.sendMailAttach(addresses, subject, content, outputInfo.getSubKey());
+				} else {
+					this.sendMail(addresses, subject, content);
+				}
 			} catch (AuthenticationFailedException e) {
 				String detailMsg = "cannot connect to the mail server due to an Authentication Failure";
 				m_log.warn("sendMail() " + e.getMessage() + " : " + detailMsg + " : "
@@ -327,6 +337,131 @@ public class SendMail implements Notifier {
 		}
 	}
 
+	/**
+	 * 添付ファイル付きのメールを送信します。
+	 * 
+	 * <p>
+	 * 下記の情報は、ファイルより取得します。
+	 * <p>
+	 * <ul>
+	 * <li>差出人アドレス</li>
+	 * <li>差出人個人名</li>
+	 * <li>返信の送信先アドレス</li>
+	 * <li>返信の送信先個人名</li>
+	 * <li>エラー送信先アドレス</li>
+	 * </ul>
+	 * 
+	 * @param address
+	 *            送信先アドレス
+	 * @param source
+	 *            出力内容
+	 * @return 送信に成功した場合、<code> true </code>
+	 * @throws MessagingException
+	 * @throws NamingException
+	 * @throws UnsupportedEncodingException
+	 */
+	public void sendMailAttach(String[] address, String subject, String content, String attachedFilePath)
+			throws MessagingException, UnsupportedEncodingException {
+		if (address == null || address.length <= 0) {
+			// 何もせず終了
+			return;
+		}
+
+		// JavaMail Sessionリソース検索
+		Session session = Session.getDefaultInstance(_properties);
+
+		Message mineMsg = new MimeMessage(session);
+
+		// 送信元メールアドレスと送信者名を指定
+		if (_fromAddress != null && _fromPersonalName != null) {
+			mineMsg.setFrom(new InternetAddress(_fromAddress, _fromPersonalName, _charsetAddress));
+		} else if (_fromAddress != null && _fromPersonalName == null) {
+			mineMsg.setFrom(new InternetAddress(_fromAddress));
+		}
+		// REPLY-TOを指定
+		if (_replyToAddress != null && _replyToPersonalName != null) {
+			InternetAddress reply[] = { new InternetAddress(_replyToAddress, _replyToPersonalName, _charsetAddress) };
+			mineMsg.setReplyTo(reply);
+			mineMsg.reply(true);
+		} else if (_replyToAddress != null && _replyToPersonalName == null) {
+			InternetAddress reply[] = { new InternetAddress(_replyToAddress) };
+			mineMsg.setReplyTo(reply);
+			mineMsg.reply(true);
+		}
+
+		// ERRORS-TOを指定
+		if (_errorsToAddress != null) {
+			mineMsg.setHeader("Errors-To", _errorsToAddress);
+		}
+
+		// 送信先メールアドレスを指定
+		InternetAddress[] toAddress = this.getAddress(address);
+		if (toAddress == null || toAddress.length <= 0) {
+			// 何もせず終了
+			return;
+		}
+		mineMsg.setRecipients(javax.mail.Message.RecipientType.TO, toAddress);
+
+		// メールの件名を指定
+		mineMsg.setSubject(MimeUtility.encodeText(subject, _charsetSubject, "B"));
+		
+		// メールの内容を指定(添付ファイルの処理を追加)
+		if(attachedFilePath == null || attachedFilePath.equals("")) {
+			mineMsg.setContent(content, "text/plain; charset=" + _charsetContent);
+		}
+		else {
+			MimeMultipart multipart = new MimeMultipart(); 
+			
+			// パート1に本文を設定 
+			MimeBodyPart bodyPart = new MimeBodyPart(); 
+			bodyPart.setContent(content, "text/plain; charset=" + _charsetContent);
+			multipart.addBodyPart(bodyPart);  // マルチパートに本文を追加 
+			
+			// パート2に添付ファイルを設定 
+			MimeBodyPart attachPart = new MimeBodyPart(); 
+			FileDataSource fds=new FileDataSource(attachedFilePath); 
+			attachPart.setDataHandler(new DataHandler(fds)); 
+			attachPart.setFileName(fds.getName());
+
+			multipart.addBodyPart(attachPart);  // マルチパートに添付ファイルを追加 
+			
+			// メールにマルチパートを設定 
+			mineMsg.setContent(multipart);
+		}
+			
+		// 送信日付を指定
+		mineMsg.setSentDate(new Date());
+
+		// 再送信フラグがtrueかつ再送回数以内の場合
+		for (int i = 0; i < _transportTries; i++) {
+			Transport transport = null;
+			try {
+				// メール送信
+				transport = session.getTransport();
+				transport.connect(_loginUser, _loginPassword);
+				transport.sendMessage(mineMsg, mineMsg.getAllRecipients());
+				break;
+			} catch (AuthenticationFailedException e) {
+				throw e;
+			} catch (SMTPAddressFailedException e) {
+				throw e;
+			} catch (MessagingException me) {
+				if (i < _transportTries) {
+					m_log.info("sendMail() : retry sendmail. " + me.getMessage());
+					try {
+						Thread.sleep(_transportTriesInterval);
+					} catch (InterruptedException e) { }
+				} else {
+					throw me;
+				}
+			} finally {
+				if (transport != null) {
+					transport.close();
+				}
+			}
+		}
+	}
+
 	/**
 	 * 引数で指定された送信先アドレスの<code> InternetAddress </code>オブジェクトを返します。
 	 * 
