@@ -82,10 +82,13 @@ public class PerformanceCreateDialog extends CommonMonitorNumericDialog {
 	 *            親のシェルオブジェクト
 	 * @param notifyId
 	 *            変更する通知ID
+	 * @param updateFlg
+	 *            更新するか否か（true:変更、false:新規登録）
 	 */
-	public PerformanceCreateDialog(Shell parent, String monitorId) {
+	public PerformanceCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
 		super(parent);
 		this.monitorId = monitorId;
+		this.updateFlg = updateFlg;
 	}
 
 	// ----- instance メソッド ----- //
@@ -130,7 +133,7 @@ public class PerformanceCreateDialog extends CommonMonitorNumericDialog {
 
 		// コンボボックス
 		this.m_comboCollectorItem =
-			new CollectorItemComboComposite(groupCheckRule, SWT.DROP_DOWN | SWT.READ_ONLY);
+				new CollectorItemComboComposite(groupCheckRule, SWT.DROP_DOWN | SWT.READ_ONLY);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -149,8 +152,8 @@ public class PerformanceCreateDialog extends CommonMonitorNumericDialog {
 
 		// 内訳フラグ
 		this.m_breakdownFlg =
-			new Button(groupCheckRule, SWT.CHECK);
-		this.m_breakdownFlg.setText("収集時は内訳のデータも合わせて収集する");
+				new Button(groupCheckRule, SWT.CHECK);
+		this.m_breakdownFlg.setText(Messages.getString("dialog.performance.monitor.collect.detail"));
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -330,7 +333,7 @@ public class PerformanceCreateDialog extends CommonMonitorNumericDialog {
 		MonitorInfo info = this.inputData;
 		if(info != null){
 			String[] args = { info.getMonitorId() };
-			if(this.monitorId == null){
+			if(!this.updateFlg){
 				// 作成の場合
 				try {
 					result = MonitorSettingEndpointWrapper.addMonitor(info);
