@@ -15,18 +15,20 @@ GNU General Public License for more details.
 
 package com.clustercontrol.performance.monitor.factory;
 
-import javax.ejb.CreateException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.commons.scheduler.TriggerScheduler;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.AddMonitorNumericValueType;
+import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
+import com.clustercontrol.monitor.run.util.QueryUtil;
 import com.clustercontrol.performance.monitor.bean.PerfCheckInfo;
-import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoUtil;
+import com.clustercontrol.performance.monitor.model.MonitorPerfInfoEntity;
 import com.clustercontrol.performance.util.PerformanceProperties;
+import com.clustercontrol.plugin.impl.SchedulerPlugin.TriggerType;
 
 
 /**
@@ -44,17 +46,18 @@ public class AddMonitorPerformance extends AddMonitorNumericValueType{
 	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#addCheckInfo()
 	 */
 	@Override
-	protected boolean addCheckInfo() throws CreateException, NamingException{
+	protected boolean addCheckInfo() throws MonitorNotFound, HinemosUnknown, InvalidRole {
 		m_log.debug("addCheckInfo() monitorId = " + m_monitorInfo.getMonitorId());
 
+		MonitorInfoEntity monitorEntity = QueryUtil.getMonitorInfoPK(m_monitorInfo.getMonitorId());
+
 		// リソース監視情報を設定
 		PerfCheckInfo perf = m_monitorInfo.getPerfCheckInfo();
 
-		MonitorPerfInfoUtil.getLocalHome().create(
-				m_monitorInfo.getMonitorId(),
-				perf.getItemCode(),
-				perf.getDeviceDisplayName(),
-				perf.getBreakdownFlg());
+		MonitorPerfInfoEntity entity = new MonitorPerfInfoEntity(monitorEntity);
+		entity.setBreakdownFlg(perf.getBreakdownFlg());
+		entity.setDeviceDisplayName(perf.getDeviceDisplayName());
+		entity.setItemCode(perf.getItemCode());
 
 		// 監視または収集が有効の場合にポーラに登録
 		boolean result = true;
@@ -85,7 +88,7 @@ public class AddMonitorPerformance extends AddMonitorNumericValueType{
 	 * スケジュール実行種別を返します。
 	 */
 	@Override
-	protected String getTriggerType() {
-		return TriggerScheduler.TRIGGER_TYPE_CRON;
+	protected TriggerType getTriggerType() {
+		return TriggerType.CRON;
 	}
 }
