@@ -24,39 +24,38 @@ import java.util.List;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.ejb.RemoveException;
-import javax.naming.NamingException;
+import javax.persistence.EntityExistsException;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.fault.FacilityNotFound;
-import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.commons.util.JmsPersistenceConfig;
+import com.clustercontrol.fault.FacilityNotFound;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.bean.MonitorRunResultInfo;
 import com.clustercontrol.monitor.run.factory.RunMonitor;
 import com.clustercontrol.monitor.run.factory.RunMonitorNumericValueType;
 import com.clustercontrol.monitor.run.util.ParallelExecution;
 import com.clustercontrol.notify.bean.OutputBasicInfo;
-import com.clustercontrol.performance.util.PerformanceDataUtil;
-import com.clustercontrol.performance.util.PollingDataManager;
-import com.clustercontrol.performance.util.code.CollectorItemCodeTable;
+import com.clustercontrol.notify.session.NotifyControllerBean;
 import com.clustercontrol.performance.bean.CollectedDataErrorTypeConstant;
 import com.clustercontrol.performance.bean.CollectorItemInfo;
 import com.clustercontrol.performance.bean.Node;
 import com.clustercontrol.performance.bean.Sample;
 import com.clustercontrol.performance.monitor.bean.PerfCheckInfo;
-import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoLocal;
-import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoUtil;
+import com.clustercontrol.performance.monitor.model.MonitorPerfInfoEntity;
 import com.clustercontrol.performance.monitor.util.CallablePerfTask;
+import com.clustercontrol.performance.monitor.util.QueryUtil;
+import com.clustercontrol.performance.util.PerformanceDataUtil;
+import com.clustercontrol.performance.util.PollingDataManager;
+import com.clustercontrol.performance.util.code.CollectorItemCodeTable;
 import com.clustercontrol.poller.NotInitializedException;
 import com.clustercontrol.repository.bean.NodeDeviceInfo;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
+import com.clustercontrol.repository.session.RepositoryControllerBean;
 import com.clustercontrol.util.Messages;
 
 /**
@@ -75,7 +74,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 	private static final String MESSAGE_ID_UNKNOWN = "004";
 
 	/** 閾値情報 */
-	private MonitorPerfInfoLocal m_perf = null;
+	private MonitorPerfInfoEntity m_perf = null;
 
 	/** 収集項目名 */
 	private String m_itemName = null;
@@ -87,7 +86,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 	 * コンストラクタ
 	 * 
 	 */
-	public RunMonitorPerformance() throws NamingException, CreateException{
+	public RunMonitorPerformance() {
 		super();
 	}
 
@@ -98,7 +97,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 	 * @see com.clustercontrol.monitor.run.util.CallableTask
 	 */
 	@Override
-	protected RunMonitor createMonitorInstance() throws NamingException, CreateException{
+	protected RunMonitor createMonitorInstance() {
 		return new RunMonitorPerformance();
 	}
 
@@ -110,8 +109,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 	 * 
 	 */
 	@Override
-	protected boolean runMonitorInfo() throws FinderException, RemoveException, NamingException, CreateException,
-	HinemosUnknown {
+	protected boolean runMonitorInfo() throws FacilityNotFound, MonitorNotFound, EntityExistsException, InvalidRole, HinemosUnknown {
 		m_log.debug("runMonitorInfo()");
 
 		m_now = new Date(System.currentTimeMillis());
@@ -139,12 +137,12 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 
 			// ファシリティIDの配下全ての一覧を取得
 			// 有効/無効フラグがtrueとなっているファシリティIDを取得する
-			ArrayList<String> facilityList = m_repository.getExecTargetFacilityIdList(m_facilityId);
+			ArrayList<String> facilityList = new RepositoryControllerBean().getExecTargetFacilityIdList(m_facilityId, m_monitor.getOwnerRoleId());
 			if (facilityList.size() == 0) {
 				return true;
 			}
 
-			m_isNode = m_repository.isNode(m_facilityId);
+			m_isNode = new RepositoryControllerBean().isNode(m_facilityId);
 
 			m_log.debug("monitor start : monitorTypeId : " + m_monitorTypeId + ", monitorId : " + m_monitorId);
 
@@ -173,7 +171,6 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 					runMonitor.setMonitorInfo(m_monitorTypeId, m_monitorId);
 					runMonitor.m_priorityMap = this.m_priorityMap;
 					runMonitor.setJudgementInfo();
-					runMonitor.m_repository = this.m_repository;
 					runMonitor.setCheckInfo();
 
 					Future<ArrayList<MonitorRunResultInfo> > future = ParallelExecution.submitPerf(new CallablePerfTask(runMonitor, facilityId));
@@ -273,23 +270,19 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 
 			return true;
 
+		} catch (EntityExistsException e) {
+			throw e;
 		} catch (FacilityNotFound e) {
-			m_log.error("runMonitorInfo(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-			throw new FinderException(e.getMessage());
-		} catch (FinderException e) {
-			m_log.error("runMonitorInfo(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
 			throw e;
-		} catch (CreateException e) {
-			m_log.error("runMonitorInfo(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
-			throw e;
-		} catch (NamingException e) {
-			m_log.error("runMonitorInfo(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
+		} catch (InvalidRole e) {
 			throw e;
 		} catch (InterruptedException e) {
-			m_log.error("runMonitorInfo(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
+			m_log.info("runMonitorInfo() monitorTypeId = " + m_monitorTypeId + ", monitorId = " + m_monitorId + " : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			return false;
 		} catch (ExecutionException e) {
-			m_log.error("runMonitorInfo(): monitorTypeId:" + m_monitorTypeId + ",monitorId:" + m_monitorId  + ", " + e.getMessage(), e);
+			m_log.info("runMonitorInfo() monitorTypeId = " + m_monitorTypeId + ", monitorId = " + m_monitorId + " : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			return false;
 		}
 	}
@@ -298,7 +291,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 	 * リソース監視はcollectList()でファシリティ毎の処理を動作するように変更
 	 */
 	@Override
-	public boolean collect(String facilityId) throws FacilityNotFound {
+	public boolean collect(String facilityId) {
 		m_log.debug("collect() monitorTypeId = " + m_monitorTypeId + ",monitorId = " + m_monitorId  + ", facilityId = " + facilityId);
 		return true;
 	}
@@ -307,7 +300,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 	 * 監視の実態。対象ノードのfacilityId毎に呼ばれる
 	 * 
 	 */
-	public ArrayList<MonitorRunResultInfo> collectList(String facilityId) throws FacilityNotFound, NamingException, CreateException, FinderException{
+	public ArrayList<MonitorRunResultInfo> collectList(String facilityId) throws FacilityNotFound {
 		m_log.debug("collectList() monitorTypeId = " + m_monitorTypeId + ",monitorId = " + m_monitorId  + ", facilityId = " + facilityId);
 
 		ArrayList<MonitorRunResultInfo> resultList = new ArrayList<MonitorRunResultInfo>();
@@ -344,7 +337,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 
 		// 2つ分のSharedTableのfetchが失敗した場合
 		if(!fetchFlg){
-			m_log.warn("collectList() SharedTable is not update. Create or replace node poller. " +
+			m_log.info("collectList() SharedTable is not update. Create or replace node poller. " +
 					"monitorTypeId = " + m_monitorTypeId + ",monitorId = " + m_monitorId  + ", facilityId = " + facilityId);
 
 			// スケジューラの再登録は条件にかまわず実施する
@@ -358,8 +351,6 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 			schedule.addNodeSchedule(facilityId, m_monitorId, m_monitor.getMonitorTypeId(), m_monitor.getRunInterval(), perfCheckInfo);
 			return resultList;
 		}
-		
-		Date d = new Date(node.getLastCollectTime());
 
 		////
 		// 全てのItemCode/deviceに対して処理を実施
@@ -449,7 +440,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 					}else{
 						result.setMonitorFlg(false);
 					}
-					
+
 					NodeDeviceInfo targetDeviceInfo = null;
 					for(NodeDeviceInfo deviceInfo : deviceList){
 						if(m_perf.getDeviceDisplayName().equals(deviceInfo.getDeviceDisplayName())){
@@ -458,7 +449,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 						}
 					}
 					m_deviceData = targetDeviceInfo;
-							
+
 					result.setCollectorFlg(true);
 					if (m_now != null) {
 						result.setNodeDate(m_now.getTime());
@@ -529,8 +520,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 			boolean isNode, String facilityId,
 			int result,
 			Date generationDate,
-			MonitorRunResultInfo resultInfo)
-	throws FinderException, NamingException {
+			MonitorRunResultInfo resultInfo) throws HinemosUnknown {
 
 		// for debug
 		if (m_log.isDebugEnabled()) {
@@ -566,7 +556,7 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 			notifyInfo.setSubKey(resultInfo.getDisplayName());
 		}
 
-		String facilityPath = m_repository.getFacilityPath(facilityId, null);
+		String facilityPath = new RepositoryControllerBean().getFacilityPath(facilityId, null);
 		notifyInfo.setFacilityId(facilityId);
 		notifyInfo.setScopeText(facilityPath);
 
@@ -596,17 +586,16 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 					+ ", generationDate = " + generationDate);
 		}
 
-		int jmsPersistence = JmsPersistenceConfig.getJmsPersistence(notifyInfo.getPluginId());
 		// ログ出力情報を送信
 		if (m_log.isDebugEnabled()) {
-			m_log.debug("sending message to jms. (" + " " + JmsPersistenceConfig.getPersistenceString(jmsPersistence) + ")"
+			m_log.debug("sending message"
 					+ " : priority=" + notifyInfo.getPriority()
 					+ " generationDate=" + notifyInfo.getGenerationDate() + " pluginId=" + notifyInfo.getPluginId()
 					+ " monitorId=" + notifyInfo.getMonitorId() + " facilityId=" + notifyInfo.getFacilityId()
 					+ " subKey=" + notifyInfo.getSubKey()
 					+ ")");
 		}
-		m_notifyController.notify(notifyInfo, notifyGroupId);
+		new NotifyControllerBean().notify(notifyInfo, notifyGroupId);
 	}
 
 
@@ -615,9 +604,9 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 	 * @see com.clustercontrol.monitor.run.factory.OperationNumericValueInfo#setMonitorAdditionInfo()
 	 */
 	@Override
-	protected void setCheckInfo() throws FinderException, NamingException{
+	protected void setCheckInfo() throws MonitorNotFound {
 		// 性能管理閾値監視情報を取得
-		m_perf = MonitorPerfInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);
+		m_perf = QueryUtil.getMonitorPerfInfoPK(m_monitorId);
 	}
 
 	/**
@@ -707,8 +696,8 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 			if(m_deviceData != null) {
 
 				valueString = valueString + "\n" +
-				Messages.getString("device.name") + " : " + m_deviceData.getDeviceName() + "\n" +
-				Messages.getString("device.index") + " : " + m_deviceData.getDeviceIndex();
+						Messages.getString("device.name") + " : " + m_deviceData.getDeviceName() + "\n" +
+						Messages.getString("device.index") + " : " + m_deviceData.getDeviceIndex();
 
 				m_log.debug("RunMonitorPerf add DeviceInfo : " + valueString);
 			}
@@ -732,18 +721,15 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 
 
 	@Override
-	protected boolean setMonitorInfo(String monitorTypeId, String monitorId) throws NamingException, CreateException, FinderException, HinemosUnknown{
+	protected boolean setMonitorInfo(String monitorTypeId, String monitorId) throws MonitorNotFound, HinemosUnknown{
 		boolean ret = super.setMonitorInfo(monitorTypeId, monitorId);
-		
+
 		// 次回が稼働日の場合はスケジュールを再作成する
 		if(!m_isInCalendarTerm && m_isInNextCalendarTerm){
 			try{
-				if(m_repository == null){
-					m_repository = RepositoryControllerUtil.getLocalHome().create();
-				}
-				
+				RepositoryControllerBean repository = new RepositoryControllerBean();
 				if(m_perf == null){
-					m_perf = MonitorPerfInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);
+					setCheckInfo();
 				}
 
 				PerfCheckInfo perfCheckInfo = new PerfCheckInfo();
@@ -754,30 +740,33 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 				perfCheckInfo.setMonitorTypeId(m_monitor.getMonitorTypeId());
 
 				ModifyPollingSchedule schedule = new ModifyPollingSchedule();
-				if(m_repository.isNode(m_facilityId)){
+				if(repository.isNode(m_facilityId)){
 					// ノードの場合
 					m_log.info("pre-schedule : monitorId = " + m_monitorId + ", facilityId = " + m_facilityId);
 					schedule.addNodeSchedule(m_facilityId, m_monitorId, m_monitor.getMonitorTypeId(), m_monitor.getRunInterval(), perfCheckInfo);
 				}
 				else{
 					// スコープの場合
-					ArrayList<String> facilityList = m_repository.getExecTargetFacilityIdList(m_facilityId);
+					ArrayList<String> facilityList = repository.getExecTargetFacilityIdList(m_facilityId, m_monitor.getOwnerRoleId());
 					if (facilityList.size() == 0) {
 						m_log.info("pre-schedule : monitorId = " + m_monitorId + ", facilityId is null");
 						return true;
 					}
-					
+
 					for (String facilityId : facilityList) {
 						m_log.info("pre-schedule : monitorId = " + m_monitorId + ", facilityId = " + facilityId);
 						schedule.addNodeSchedule(facilityId, m_monitorId, m_monitor.getMonitorTypeId(), m_monitor.getRunInterval(), perfCheckInfo);
 					}
 				}
-				
+
 			} catch (FacilityNotFound e) {
 				m_log.warn("setMonitorInfo() : fail to addSchedule . m_monitorId = " + m_monitorId, e);
+			} catch (InvalidRole e) {
+				m_log.warn("setMonitorInfo() : fail to addSchedule . m_monitorId = " + m_monitorId, e);
 			}
 		}
 
 		return ret;
 	}
+
 }
\ No newline at end of file
