@@ -69,16 +69,16 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 	private Button m_radioService = null;
 
 	/** サービスプロトコル */
-	protected Combo m_comboService = null;
+	private Combo m_comboService = null;
 
 	/** ポート番号 */
-	protected Text m_textPortNo = null;
+	private Text m_textPortNo = null;
 
 	/** 実行回数 */
-	protected Combo m_comboRunCount = null;
+	private Combo m_comboRunCount = null;
 
 	/** 実行間隔（秒） */
-	protected Combo m_comboRunInterval = null;
+	private Combo m_comboRunInterval = null;
 
 	// ----- コンストラクタ ----- //
 
@@ -99,11 +99,15 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 	 *            親のシェルオブジェクト
 	 * @param notifyId
 	 *            変更する通知ID
+	 * @param updateFlg
+	 *            更新するか否か（true:変更、false:新規登録）
+	 * 
 	 */
-	public PortCreateDialog(Shell parent, String monitorId) {
+	public PortCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
 		super(parent);
 
 		this.monitorId = monitorId;
+		this.updateFlg = updateFlg;
 	}
 
 	// ----- instance メソッド ----- //
@@ -377,7 +381,7 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 
 	}
 
-	private void setEnabledComboService(boolean enable) {
+	protected void setEnabledComboService(boolean enable) {
 		this.m_comboService.setEnabled(enable);
 	}
 
@@ -545,7 +549,7 @@ public class PortCreateDialog extends CommonMonitorNumericDialog {
 		MonitorInfo info = this.inputData;
 		if(info != null){
 			String[] args = { info.getMonitorId() };
-			if(this.monitorId == null){
+			if(!this.updateFlg){
 				// 作成の場合
 				try {
 					result = MonitorSettingEndpointWrapper.addMonitor(info);
