@@ -24,6 +24,7 @@ import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
+import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
@@ -60,6 +61,9 @@ public class ProcessCreateDialog extends CommonMonitorNumericDialog {
 	/** 引数 */
 	private Text m_textParam = null;
 
+	/** 大文字・小文字を区別しない */
+	private Button m_checkCaseSensitive = null;
+
 	// ----- コンストラクタ ----- //
 
 	/**
@@ -79,11 +83,15 @@ public class ProcessCreateDialog extends CommonMonitorNumericDialog {
 	 *            親のシェルオブジェクト
 	 * @param notifyId
 	 *            変更する通知ID
+	 * @param updateFlg
+	 *            更新するか否か（true:変更、false:新規登録）
+	 * 
 	 */
-	public ProcessCreateDialog(Shell parent, String monitorId) {
+	public ProcessCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
 		super(parent);
 
 		this.monitorId = monitorId;
+		this.updateFlg = updateFlg;
 	}
 
 	// ----- instance メソッド ----- //
@@ -188,6 +196,23 @@ public class ProcessCreateDialog extends CommonMonitorNumericDialog {
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 
+		// 大文字・小文字をチェックしない
+		this.m_checkCaseSensitive = new Button(groupCheckRule, SWT.CHECK);
+		gridData = new GridData();
+		gridData.horizontalSpan = 8;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		this.m_checkCaseSensitive.setLayoutData(gridData);
+		this.m_checkCaseSensitive.setText(Messages.getString("case.sensitive"));
+
+		// 空白
+		label = new Label(groupCheckRule, SWT.NONE);
+		gridData = new GridData();
+		gridData.horizontalSpan = 7;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setLayoutData(gridData);
+
 		// 収集値表示名のデフォルト値を設定
 		this.itemName.setText(Messages.getString("process.number"));
 
@@ -268,6 +293,9 @@ public class ProcessCreateDialog extends CommonMonitorNumericDialog {
 		if (processInfo.getParam() != null) {
 			this.m_textParam.setText(processInfo.getParam());
 		}
+		if (processInfo.isCaseSensitivityFlg()){
+			this.m_checkCaseSensitive.setSelection(true);
+		}
 
 		// commandが必須項目であることを明示
 		this.update();
@@ -303,6 +331,12 @@ public class ProcessCreateDialog extends CommonMonitorNumericDialog {
 				&& !"".equals((this.m_textParam.getText()).trim())) {
 			processInfo.setParam(this.m_textParam.getText());
 		}
+		if (this.m_checkCaseSensitive.getSelection()){
+			processInfo.setCaseSensitivityFlg(true);
+		}else{
+			processInfo.setCaseSensitivityFlg(false);
+		}
+
 		monitorInfo.setProcessCheckInfo(processInfo);
 
 		// 結果判定の定義
@@ -343,7 +377,7 @@ public class ProcessCreateDialog extends CommonMonitorNumericDialog {
 		MonitorInfo info = this.inputData;
 		if(info != null){
 			String[] args = { info.getMonitorId() };
-			if(this.monitorId == null){
+			if(!this.updateFlg){
 				// 作成の場合
 				try {
 					result = MonitorSettingEndpointWrapper.addMonitor(info);
