@@ -46,6 +46,9 @@ public class GetNodeListTableDefine {
 	/** 注釈 */
 	public static final int DESCRIPTION = 4;
 
+	/** オーナーロール */
+	public static final int OWNER_ROLE = 5;
+
 	/** 初期表示時ソートカラム */
 	public static final int SORT_COLUMN_INDEX = FACILITY_ID;
 
@@ -81,6 +84,9 @@ public class GetNodeListTableDefine {
 		tableDefine.add(DESCRIPTION,
 				new TableColumnInfo(Messages.getString("description", locale),
 						TableColumnInfo.NONE, 200, SWT.LEFT));
+		tableDefine.add(OWNER_ROLE,
+				new TableColumnInfo(Messages.getString("owner.role.id", locale),
+						TableColumnInfo.NONE, 130, SWT.LEFT));
 
 		return tableDefine;
 	}
