@@ -27,6 +27,10 @@ import com.clustercontrol.repository.bean.NodeNoteInfo;
 /**
  * このクラスはノード詳細のクラスです。
  * ノードの詳細を保持するために使用されます。
+ * 
+ * TODO
+ * HinemosClientのNodePropertyUtil.javaのsetDefaultNodeと値をあわせておくこと！
+ * 
  * @since 0.8
  */
 @XmlType(namespace = "http://repository.ws.clustercontrol.com")
@@ -36,11 +40,11 @@ public class NodeInfo extends FacilityInfo implements Serializable
 
 	// HW
 	private java.lang.String platformFamily = "";
+	private java.lang.String subPlatformFamily = "";
 	private java.lang.String hardwareType = "";
-	private java.lang.String iconImage = "";
 
 	// IPアドレス
-	private java.lang.Integer ipAddressVersion = new Integer(-1);
+	private java.lang.Integer ipAddressVersion = null;
 	private java.lang.String ipAddressV4 = "";
 	private java.lang.String ipAddressV6 = "";
 	private ArrayList<NodeHostnameInfo> nodeHostnameInfo;
@@ -52,29 +56,35 @@ public class NodeInfo extends FacilityInfo implements Serializable
 	private java.lang.String osVersion = "";
 	private java.lang.String characterSet = "";
 
+	// Hinemosエージェント
+	private java.lang.Integer agentAwakePort = null;
+
+	// JOB
+	private java.lang.Integer jobPriority = null;
+	private java.lang.Integer jobMultiplicity = null;
+
 	// SNMP
-	private java.lang.Integer snmpPort = new Integer(-1);
+	private java.lang.Integer snmpPort = null;
 	private java.lang.String snmpCommunity = "";
 	private java.lang.String snmpVersion = "";
-	private java.lang.Integer snmpTimeout = new Integer(-1);
-	private java.lang.Integer snmpRetryCount = new Integer(-1);
-	private java.lang.String snmpProxy = "";
+	private java.lang.Integer snmpTimeout = null;
+	private java.lang.Integer snmpRetryCount = null;
 
 	// WBEM
 	private java.lang.String wbemUser = "";
 	private java.lang.String wbemUserPassword = "";
-	private java.lang.Integer wbemPort = new Integer(-1);
+	private java.lang.Integer wbemPort = null;
 	private java.lang.String wbemProtocol = "";
-	private java.lang.Integer wbemTimeout = new Integer(-1);
-	private java.lang.Integer wbemRetryCount = new Integer(-1);
+	private java.lang.Integer wbemTimeout = null;
+	private java.lang.Integer wbemRetryCount = null;
 
 	// IPMI
 	private java.lang.String ipmiIpAddress = "";
-	private java.lang.Integer ipmiPort = new Integer(-1);
+	private java.lang.Integer ipmiPort = null;
 	private java.lang.String ipmiUser = "";
 	private java.lang.String ipmiUserPassword = "";
-	private java.lang.Integer ipmiTimeout = new Integer(-1);
-	private java.lang.Integer ipmiRetries = new Integer(-1);
+	private java.lang.Integer ipmiTimeout = null;
+	private java.lang.Integer ipmiRetries = null;
 	private java.lang.String ipmiProtocol = "";
 	private java.lang.String ipmiLevel = "";
 
@@ -82,10 +92,10 @@ public class NodeInfo extends FacilityInfo implements Serializable
 	private java.lang.String winrmUser = "";
 	private java.lang.String winrmUserPassword = "";
 	private java.lang.String winrmVersion = "";
-	private java.lang.Integer winrmPort = new Integer(-1);
+	private java.lang.Integer winrmPort = null;
 	private java.lang.String winrmProtocol = "";
-	private java.lang.Integer winrmTimeout = new Integer(-1);
-	private java.lang.Integer winrmRetries = new Integer(-1);
+	private java.lang.Integer winrmTimeout = null;
+	private java.lang.Integer winrmRetries = null;
 
 	// デバイス
 	private ArrayList<NodeDeviceInfo> nodeDeviceInfo;
@@ -96,11 +106,9 @@ public class NodeInfo extends FacilityInfo implements Serializable
 	private ArrayList<NodeFilesystemInfo> nodeFilesystemInfo;
 
 	// サーバ仮想化
-	private java.lang.String virtualizationNodeType = "";
+	private java.lang.String vmNodeType = "";
 	private java.lang.String vmManagementNode = "";
-	private java.lang.Integer vmIndex = new Integer(-1);
 	private java.lang.String vmName = "";
-	private java.lang.String virtualizationSolution = "";
 	private java.lang.String vmId = "";
 	private java.lang.String vmUser = "";
 	private java.lang.String vmUserPassword = "";
@@ -112,6 +120,15 @@ public class NodeInfo extends FacilityInfo implements Serializable
 	private java.lang.String openFlowDataPathId = "";
 	private java.lang.String openFlowCtrlIpAddress = "";
 
+	// クラウド
+	private java.lang.String cloudNodeType = "";
+	private java.lang.String cloudService = "";
+	private java.lang.String cloudAccountResouce = "";
+	private java.lang.String cloudResourceType = "";
+	private java.lang.String cloudResourceId = "";
+	private java.lang.String cloudRegion = "";
+	private java.lang.String cloudZone = "";
+
 	// ノード変数
 	private ArrayList<NodeVariableInfo> nodeVariableInfo;
 
@@ -178,6 +195,22 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		this.platformFamily = platformFamily;
 	}
 
+	/**
+	 * サブプラットフォームのgetterです。
+	 * @return String
+	 */
+	public java.lang.String getSubPlatformFamily() {
+		return subPlatformFamily;
+	}
+
+	/**
+	 * サブプラットフォームのsetterです。
+	 * @param subPlatformFamily
+	 */
+	public void setSubPlatformFamily(java.lang.String subPlatformFamily) {
+		this.subPlatformFamily = subPlatformFamily;
+	}
+
 	/**
 	 * H/Wのgetterです。
 	 * @return String
@@ -196,24 +229,6 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		this.hardwareType = hardwareType;
 	}
 
-	/**
-	 * 画面アイコンイメージのgetterです。
-	 * @return String
-	 */
-	public java.lang.String getIconImage()
-	{
-		return this.iconImage;
-	}
-
-	/**
-	 * 画面アイコンイメージのsetterです。
-	 * @param iconImage
-	 */
-	public void setIconImage( java.lang.String iconImage )
-	{
-		this.iconImage = iconImage;
-	}
-
 	/**
 	 * SNMP->ポート番号のgetterです。
 	 * @return Integer
@@ -304,24 +319,6 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		this.snmpRetryCount = snmpRetryCount;
 	}
 
-	/**
-	 * SNMP->SNMP プロキシのgetterです。
-	 * @return String
-	 */
-	public java.lang.String getSnmpProxy()
-	{
-		return this.snmpProxy;
-	}
-
-	/**
-	 * SNMP->SNMP プロキシのsetterです。
-	 * @param snmpProxy
-	 */
-	public void setSnmpProxy( java.lang.String snmpProxy )
-	{
-		this.snmpProxy = snmpProxy;
-	}
-
 	/**
 	 * WBEM->接続ユーザ名のgetterです。
 	 * @return String
@@ -584,6 +581,61 @@ public class NodeInfo extends FacilityInfo implements Serializable
 	}
 
 
+	/**
+	 * Hinemosエージェントのawakeポートのgetter
+	 * @return String
+	 */
+	public java.lang.Integer getAgentAwakePort() {
+		return this.agentAwakePort;
+	}
+
+	/**
+	 * Hinemosエージェントのawakeポートのsetter
+	 * @param agentAwakePort
+	 */
+	public void setAgentAwakePort(java.lang.Integer agentAwakePort) {
+		this.agentAwakePort = agentAwakePort;
+	}
+
+
+	/**
+	 * ジョブ優先度のgetterです。
+	 * @return Integer
+	 */
+	public java.lang.Integer getJobPriority()
+	{
+		return this.jobPriority;
+	}
+
+	/**
+	 * ジョブ優先度のsetterです。
+	 * @param jobPriority
+	 */
+	public void setJobPriority( java.lang.Integer jobPriority )
+	{
+		this.jobPriority = jobPriority;
+	}
+
+
+	/**
+	 * ジョブ多重度のgetterです。
+	 * @return Integer
+	 */
+	public java.lang.Integer getJobMultiplicity()
+	{
+		return this.jobMultiplicity;
+	}
+
+	/**
+	 * ジョブ多重度のsetterです。
+	 * @param jobMultiplicity
+	 */
+	public void setJobMultiplicity( java.lang.Integer jobMultiplicity )
+	{
+		this.jobMultiplicity = jobMultiplicity;
+	}
+
+
 	/**
 	 * IPMI接続アドレスのgetter
 	 * @return ipmiIpAddress
@@ -828,18 +880,16 @@ public class NodeInfo extends FacilityInfo implements Serializable
 	 * 仮想化->ノード種別のgetterです。
 	 * @return String
 	 */
-	public java.lang.String getVirtualizationNodeType()
-	{
-		return this.virtualizationNodeType;
+	public java.lang.String getVmNodeType() {
+		return vmNodeType;
 	}
 
 	/**
 	 * 仮想化->ノード種別のsetterです。
-	 * @param virtualizationNodeType
+	 * @param vmNodeType
 	 */
-	public void setVirtualizationNodeType( java.lang.String virtualizationNodeType )
-	{
-		this.virtualizationNodeType = virtualizationNodeType;
+	public void setVmNodeType(java.lang.String vmNodeType) {
+		this.vmNodeType = vmNodeType;
 	}
 
 	/**
@@ -860,24 +910,6 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		this.vmManagementNode = vmManagementNode;
 	}
 
-	/**
-	 * 仮想マシンINDEXのgetterです。
-	 * @return Integer
-	 */
-	public java.lang.Integer getVmIndex()
-	{
-		return this.vmIndex;
-	}
-
-	/**
-	 * 仮想マシンINDEXのsetterです。
-	 * @param vmIndex
-	 */
-	public void setVmIndex( java.lang.Integer vmIndex )
-	{
-		this.vmIndex = vmIndex;
-	}
-
 	/**
 	 * 仮想マシン名のgetterです。
 	 * @return String
@@ -896,24 +928,6 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		this.vmName = vmName;
 	}
 
-	/**
-	 * 仮想化ソリューションのgetterです。
-	 * @return String
-	 */
-	public java.lang.String getVirtualizationSolution()
-	{
-		return this.virtualizationSolution;
-	}
-
-	/**
-	 * 仮想化ソリューションのsetterです。
-	 * @param virtualizationSolution
-	 */
-	public void setVirtualizationSolution( java.lang.String virtualizationSolution )
-	{
-		this.virtualizationSolution = virtualizationSolution;
-	}
-
 	/**
 	 * 仮想マシンIDのgetterです。
 	 * @return String
@@ -1050,6 +1064,117 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		this.openFlowCtrlIpAddress = openFlowCtrlIpAddress;
 	}
 
+	/**
+	 * クラウド管理->ノード種別のgetterです。
+	 * @return String
+	 */
+	public java.lang.String getCloudNodeType() {
+		return cloudNodeType;
+	}
+
+	/**
+	 * クラウド管理->ノード種別のsetterです。
+	 * @param cloudNodeType
+	 */
+	public void setCloudNodeType(java.lang.String cloudNodeType) {
+		this.cloudNodeType = cloudNodeType;
+	}
+
+	/**
+	 * クラウド管理->クラウドサービスのgetterです。
+	 * @return String
+	 */
+	public java.lang.String getCloudService() {
+		return cloudService;
+	}
+
+	/**
+	 * クラウド管理->クラウドサービスのsetterです。
+	 * @param cloudService
+	 */
+	public void setCloudService(java.lang.String cloudService) {
+		this.cloudService = cloudService;
+	}
+
+	/**
+	 * クラウド管理->クラウドアカウントリソースのgetterです。
+	 * @return String
+	 */
+	public java.lang.String getCloudAccountResouce() {
+		return cloudAccountResouce;
+	}
+
+	/**
+	 * クラウド管理->クラウドアカウントリソースのsetterです。
+	 * @param cloudAccountResouce
+	 */
+	public void setCloudAccountResouce(java.lang.String cloudAccountResouce) {
+		this.cloudAccountResouce = cloudAccountResouce;
+	}
+
+	/**
+	 * クラウド管理->クラウドリソースタイプのgetterです。
+	 * @return String
+	 */
+	public java.lang.String getCloudResourceType() {
+		return cloudResourceType;
+	}
+
+	/**
+	 * クラウド管理->クラウドリソースタイプのsetterです。
+	 * @param cloudResourceType
+	 */
+	public void setCloudResourceType(java.lang.String cloudResourceType) {
+		this.cloudResourceType = cloudResourceType;
+	}
+
+	/**
+	 * クラウド管理->クラウドリソースIdのgetterです。
+	 * @return String
+	 */
+	public java.lang.String getCloudResourceId() {
+		return cloudResourceId;
+	}
+
+	/**
+	 * クラウド管理->クラウドリソースIdのsetterです。
+	 * @param cloudResourceId
+	 */
+	public void setCloudResourceId(java.lang.String cloudResourceId) {
+		this.cloudResourceId = cloudResourceId;
+	}
+
+	/**
+	 * クラウド管理->リージョンのgetterです。
+	 * @return String
+	 */
+	public java.lang.String getCloudRegion() {
+		return cloudRegion;
+	}
+
+	/**
+	 * クラウド管理->リージョンのsetterです。
+	 * @param cloudRegion
+	 */
+	public void setCloudRegion(java.lang.String cloudRegion) {
+		this.cloudRegion = cloudRegion;
+	}
+
+	/**
+	 * クラウド管理->ゾーンのgetterです。
+	 * @return String
+	 */
+	public java.lang.String getCloudZone() {
+		return cloudZone;
+	}
+
+	/**
+	 * クラウド管理->ゾーンのsetterです。
+	 * @param cloudZone
+	 */
+	public void setCloudZone(java.lang.String cloudZone) {
+		this.cloudZone = cloudZone;
+	}
 
 	/**
 	 * ノード変数のgetter
@@ -1114,6 +1239,7 @@ public class NodeInfo extends FacilityInfo implements Serializable
 
 		str.append(
 				"platformFamily=" + getPlatformFamily() + " " +
+				"subPlatformFamily=" + getSubPlatformFamily() + " " +
 				"hardwareType=" + getHardwareType() + " " +
 				"iconImage=" + getIconImage() + " " +
 
@@ -1127,12 +1253,13 @@ public class NodeInfo extends FacilityInfo implements Serializable
 				"osVersion=" + getOsVersion() + " " +
 				"characterSet=" + getCharacterSet() + " " +
 
+				"agentAwakePort=" + getAgentAwakePort() + " " +
+
 				"snmpPort=" + getSnmpPort() + " " +
 				"snmpCommunity=" + getSnmpCommunity() + " " +
 				"snmpVersion=" + getSnmpVersion() + " " +
 				"snmpTimeout=" + getSnmpTimeout() + " " +
 				"snmpRetryCount=" + getSnmpRetryCount() + " " +
-				"snmpProxy=" + getSnmpProxy() + " " +
 
 				"wbemUser=" + getWbemUser() + " " +
 				"wbemUserPassword=" + getWbemUserPassword() + " " +
@@ -1150,11 +1277,9 @@ public class NodeInfo extends FacilityInfo implements Serializable
 				"ipmiProtocol=" + getIpmiProtocol() + " " +
 				"ipmiLevel=" + getIpmiLevel() + " " +
 
-				"virtualizationNodeType=" + getVirtualizationNodeType() + " " +
+				"vmNodeType=" + getVmNodeType() + " " +
 				"vmManagementNode=" + getVmManagementNode() + " " +
-				"vmIndex=" + getVmIndex() + " " +
 				"vmName=" + getVmName() + " " +
-				"virtualizationSolution=" + getVirtualizationSolution() + " " +
 				"vmId=" + getVmId() + " " +
 				"vmUser=" + getVmUser() + " " +
 				"vmUserPassword=" + getVmUserPassword() + " " +
@@ -1165,9 +1290,17 @@ public class NodeInfo extends FacilityInfo implements Serializable
 				"openFlowDataPathId=" + getOpenFlowDataPathId() + " " +
 				"openFlowCtrlIpAddress=" + getOpenFlowCtrlIpAddress() + " " +
 
+				"cloudNodeType=" + getCloudNodeType() + " " +
+				"cloudService=" + getCloudService() + " " +
+				"cloudAccountResouce=" + getCloudAccountResouce() + " " +
+				"cloudResourceType=" + getCloudResourceType() + " " +
+				"cloudResourceId=" + getCloudResourceId() + " " +
+				"cloudRegion=" + getCloudRegion() + " " +
+				"cloudZone=" + getCloudZone() + " " +
+
 				"administrator=" + getAdministrator() + " " +
 				"contact=" + getContact()
-		);
+				);
 		str.append('}');
 
 		return(str.toString());
@@ -1192,6 +1325,14 @@ public class NodeInfo extends FacilityInfo implements Serializable
 			{
 				lEquals = lEquals && this.platformFamily.equals( lTest.platformFamily );
 			}
+			if( this.subPlatformFamily == null )
+			{
+				lEquals = lEquals && ( lTest.subPlatformFamily == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.subPlatformFamily.equals( lTest.subPlatformFamily );
+			}
 			if( this.hardwareType == null )
 			{
 				lEquals = lEquals && ( lTest.hardwareType == null );
@@ -1200,14 +1341,6 @@ public class NodeInfo extends FacilityInfo implements Serializable
 			{
 				lEquals = lEquals && this.hardwareType.equals( lTest.hardwareType );
 			}
-			if( this.iconImage == null )
-			{
-				lEquals = lEquals && ( lTest.iconImage == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.iconImage.equals( lTest.iconImage );
-			}
 
 			// IP アドレス
 			if( this.ipAddressVersion == null )
@@ -1277,6 +1410,16 @@ public class NodeInfo extends FacilityInfo implements Serializable
 				lEquals = lEquals && this.characterSet.equals( lTest.characterSet );
 			}
 
+			// Hinemosエージェント
+			if( this.agentAwakePort == null )
+			{
+				lEquals = lEquals && ( lTest.agentAwakePort == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.agentAwakePort.equals( lTest.agentAwakePort );
+			}
+
 			// SNMP
 			if( this.snmpPort == null )
 			{
@@ -1318,14 +1461,6 @@ public class NodeInfo extends FacilityInfo implements Serializable
 			{
 				lEquals = lEquals && this.snmpRetryCount.equals( lTest.snmpRetryCount );
 			}
-			if( this.snmpProxy == null )
-			{
-				lEquals = lEquals && ( lTest.snmpProxy == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.snmpProxy.equals( lTest.snmpProxy );
-			}
 
 			// WBEM
 			if( this.wbemUser == null )
@@ -1445,13 +1580,13 @@ public class NodeInfo extends FacilityInfo implements Serializable
 
 
 			// サーバ仮想化
-			if( this.virtualizationNodeType == null )
+			if( this.vmNodeType == null )
 			{
-				lEquals = lEquals && ( lTest.virtualizationNodeType == null );
+				lEquals = lEquals && ( lTest.vmNodeType == null );
 			}
 			else
 			{
-				lEquals = lEquals && this.virtualizationNodeType.equals( lTest.virtualizationNodeType );
+				lEquals = lEquals && this.vmNodeType.equals( lTest.vmNodeType );
 			}
 			if( this.vmManagementNode == null )
 			{
@@ -1461,14 +1596,6 @@ public class NodeInfo extends FacilityInfo implements Serializable
 			{
 				lEquals = lEquals && this.vmManagementNode.equals( lTest.vmManagementNode );
 			}
-			if( this.vmIndex == null )
-			{
-				lEquals = lEquals && ( lTest.vmIndex == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.vmIndex.equals( lTest.vmIndex );
-			}
 			if( this.vmName == null )
 			{
 				lEquals = lEquals && ( lTest.vmName == null );
@@ -1477,14 +1604,6 @@ public class NodeInfo extends FacilityInfo implements Serializable
 			{
 				lEquals = lEquals && this.vmName.equals( lTest.vmName );
 			}
-			if( this.virtualizationSolution == null )
-			{
-				lEquals = lEquals && ( lTest.virtualizationSolution == null );
-			}
-			else
-			{
-				lEquals = lEquals && this.virtualizationSolution.equals( lTest.virtualizationSolution );
-			}
 			if( this.vmId == null )
 			{
 				lEquals = lEquals && ( lTest.vmId == null );
@@ -1552,6 +1671,64 @@ public class NodeInfo extends FacilityInfo implements Serializable
 				lEquals = lEquals && this.openFlowCtrlIpAddress.equals( lTest.openFlowCtrlIpAddress );
 			}
 
+			// クラウド管理
+			if( this.cloudNodeType == null )
+			{
+				lEquals = lEquals && ( lTest.cloudNodeType == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.cloudNodeType.equals( lTest.cloudNodeType );
+			}
+			if( this.cloudService == null )
+			{
+				lEquals = lEquals && ( lTest.cloudService == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.cloudService.equals( lTest.cloudService );
+			}
+			if( this.cloudAccountResouce == null )
+			{
+				lEquals = lEquals && ( lTest.cloudAccountResouce == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.cloudAccountResouce.equals( lTest.cloudAccountResouce );
+			}
+			if( this.cloudResourceType == null )
+			{
+				lEquals = lEquals && ( lTest.cloudResourceType == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.cloudResourceType.equals( lTest.cloudResourceType );
+			}
+			if( this.cloudResourceId == null )
+			{
+				lEquals = lEquals && ( lTest.cloudResourceId == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.cloudResourceId.equals( lTest.cloudResourceId );
+			}
+			if( this.cloudRegion == null )
+			{
+				lEquals = lEquals && ( lTest.cloudRegion == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.cloudRegion.equals( lTest.cloudRegion );
+			}
+			if( this.cloudZone == null )
+			{
+				lEquals = lEquals && ( lTest.cloudZone == null );
+			}
+			else
+			{
+				lEquals = lEquals && this.cloudZone.equals( lTest.cloudZone );
+			}
+
 			// 保守
 			if( this.administrator == null )
 			{
@@ -1586,15 +1763,14 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		result = 37*result + super.hashCode();
 
 		result = 37*result + ((this.platformFamily != null) ? this.platformFamily.hashCode() : 0);
+		result = 37*result + ((this.subPlatformFamily != null) ? this.subPlatformFamily.hashCode() : 0);
 		result = 37*result + ((this.hardwareType != null) ? this.hardwareType.hashCode() : 0);
-		result = 37*result + ((this.iconImage != null) ? this.iconImage.hashCode() : 0);
 
 		result = 37*result + ((this.snmpPort != null) ? this.snmpPort.hashCode() : 0);
 		result = 37*result + ((this.snmpCommunity != null) ? this.snmpCommunity.hashCode() : 0);
 		result = 37*result + ((this.snmpVersion != null) ? this.snmpVersion.hashCode() : 0);
 		result = 37*result + ((this.snmpTimeout != null) ? this.snmpTimeout.hashCode() : 0);
 		result = 37*result + ((this.snmpRetryCount != null) ? this.snmpRetryCount.hashCode() : 0);
-		result = 37*result + ((this.snmpProxy != null) ? this.snmpProxy.hashCode() : 0);
 
 		result = 37*result + ((this.wbemUser != null) ? this.wbemUser.hashCode() : 0);
 		result = 37*result + ((this.wbemUserPassword != null) ? this.wbemUserPassword.hashCode() : 0);
@@ -1613,19 +1789,27 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		result = 37*result + ((this.osVersion != null) ? this.osVersion.hashCode() : 0);
 		result = 37*result + ((this.characterSet != null) ? this.characterSet.hashCode() : 0);
 
-		result = 37*result + ((this.virtualizationNodeType != null) ? this.virtualizationNodeType.hashCode() : 0);
+		result = 37*result + ((this.vmNodeType != null) ? this.vmNodeType.hashCode() : 0);
 		result = 37*result + ((this.vmManagementNode != null) ? this.vmManagementNode.hashCode() : 0);
-		result = 37*result + ((this.vmIndex != null) ? this.vmIndex.hashCode() : 0);
 		result = 37*result + ((this.vmName != null) ? this.vmName.hashCode() : 0);
-		result = 37*result + ((this.virtualizationSolution != null) ? this.virtualizationSolution.hashCode() : 0);
 		result = 37*result + ((this.vmId != null) ? this.vmId.hashCode() : 0);
 		result = 37*result + ((this.vmUser != null) ? this.vmUser.hashCode() : 0);
 		result = 37*result + ((this.vmUserPassword != null) ? this.vmUserPassword.hashCode() : 0);
 		result = 37*result + ((this.vmProtocol != null) ? this.vmProtocol.hashCode() : 0);
 
+		result = 37*result + ((this.cloudNodeType != null) ? this.cloudNodeType.hashCode() : 0);
+		result = 37*result + ((this.cloudService != null) ? this.cloudService.hashCode() : 0);
+		result = 37*result + ((this.cloudAccountResouce != null) ? this.cloudAccountResouce.hashCode() : 0);
+		result = 37*result + ((this.cloudResourceType != null) ? this.cloudResourceType.hashCode() : 0);
+		result = 37*result + ((this.cloudResourceId != null) ? this.cloudResourceId.hashCode() : 0);
+		result = 37*result + ((this.cloudRegion != null) ? this.cloudRegion.hashCode() : 0);
+		result = 37*result + ((this.cloudZone != null) ? this.cloudZone.hashCode() : 0);
+		
 		result = 37*result + ((this.administrator != null) ? this.administrator.hashCode() : 0);
 		result = 37*result + ((this.contact != null) ? this.contact.hashCode() : 0);
 
+		result = 37*result + ((this.agentAwakePort != null) ? this.agentAwakePort.hashCode() : 0);
+
 		return result;
 	}
 
@@ -1776,4 +1960,99 @@ public class NodeInfo extends FacilityInfo implements Serializable
 		}
 		return ipAddress;
 	}
+
+	/**
+	 * メンバ変数にnullが含まれていた場合は、デフォルト値を設定する。
+	 */
+	public void setDefaultInfo() {
+		// HW
+		if (platformFamily == null) platformFamily = "";
+		if (subPlatformFamily == null) subPlatformFamily = "";
+		if (hardwareType == null) hardwareType = "";
+
+		// IPアドレス
+		if (ipAddressVersion == null) ipAddressVersion = null;
+		if (ipAddressV4 == null) ipAddressV4 = "";
+		if (ipAddressV6 == null) ipAddressV6 = "";
+
+		// OS
+		if (nodeName == null) nodeName = "";
+		if (osName == null) osName = "";
+		if (osRelease == null) osRelease = "";
+		if (osVersion == null) osVersion = "";
+		if (characterSet == null) characterSet = "";
+
+		// Hinemosエージェント
+		if (agentAwakePort == null) agentAwakePort = 24005;
+
+		// JOB
+		if (jobPriority == null) jobPriority = 16;
+		if (jobMultiplicity == null) jobMultiplicity = 0;
+
+		// SNMP
+		if (snmpPort == null) snmpPort = 161;
+		if (snmpCommunity == null) snmpCommunity = "";
+		if (snmpVersion == null) snmpVersion = "";
+		if (snmpTimeout == null) snmpTimeout = 5000;
+		if (snmpRetryCount == null) snmpRetryCount = 3;
+
+		// WBEM
+		if (wbemUser == null) wbemUser = "";
+		if (wbemUserPassword == null) wbemUserPassword = "";
+		if (wbemPort == null) wbemPort = 5988;
+		if (wbemProtocol == null) wbemProtocol = "";
+		if (wbemTimeout == null) wbemTimeout = 5000;
+		if (wbemRetryCount == null) wbemRetryCount = 3;
+
+		// IPMI
+		if (ipmiIpAddress == null) ipmiIpAddress = "";
+		if (ipmiPort == null) ipmiPort = 0;
+		if (ipmiUser == null) ipmiUser = "";
+		if (ipmiUserPassword == null) ipmiUserPassword = "";
+		if (ipmiTimeout == null) ipmiTimeout = 5000;
+		if (ipmiRetries == null) ipmiRetries = 3;
+		if (ipmiProtocol == null) ipmiProtocol = "";
+		if (ipmiLevel == null) ipmiLevel = "";
+
+		// WinRM
+		if (winrmUser == null) winrmUser = "";
+		if (winrmUserPassword == null) winrmUserPassword = "";
+		if (winrmVersion == null) winrmVersion = "";
+		if (winrmPort == null) winrmPort = 5985;
+		if (winrmProtocol == null) winrmProtocol = "";
+		if (winrmTimeout == null) winrmTimeout = 5000;
+		if (winrmRetries == null) winrmRetries = 3;
+
+		// デバイス
+
+		// サーバ仮想化
+		if (vmNodeType == null) vmNodeType = "";
+		if (vmManagementNode == null) vmManagementNode = "";
+		if (vmName == null) vmName = "";
+		if (vmId == null) vmId = "";
+		if (vmUser == null) vmUser = "";
+		if (vmUserPassword == null) vmUserPassword = "";
+		if (vmProtocol == null) vmProtocol = "";
+
+		// ネットワーク仮想化
+		if (vNetSwitchType == null) vNetSwitchType = "";
+		if (vNetHostNode == null) vNetHostNode = "";
+		if (openFlowDataPathId == null) openFlowDataPathId = "";
+		if (openFlowCtrlIpAddress == null) openFlowCtrlIpAddress = "";
+
+		// サーバ仮想化
+		if (cloudNodeType == null) cloudNodeType = "";
+		if (cloudService == null) cloudService = "";
+		if (cloudAccountResouce == null) cloudAccountResouce = "";
+		if (cloudResourceType == null) cloudResourceType = "";
+		if (cloudResourceId == null) cloudResourceId = "";
+		if (cloudRegion == null) cloudRegion = "";
+		if (cloudZone == null) cloudZone = "";
+
+		// ノード変数
+
+		// 保守
+		if (administrator == null) administrator = "";
+		if (contact == null) contact = "";
+	}
 }
