@@ -28,13 +28,12 @@ import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.TableTree;
+import org.eclipse.swt.custom.TableTreeItem;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
-import org.eclipse.swt.layout.RowData;
-import org.eclipse.swt.layout.RowLayout;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
@@ -44,29 +43,25 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
-import com.clustercontrol.ClusterControlPlugin;
-import com.clustercontrol.action.FacilityTree;
+import com.clustercontrol.accesscontrol.util.LocalSession;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.bean.PropertyConstant;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
-import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.SnmpVersionConstant;
-import com.clustercontrol.composite.PropertySheet;
+import com.clustercontrol.composite.RoleIdListComposite;
+import com.clustercontrol.composite.RoleIdListComposite.Mode;
 import com.clustercontrol.dialog.CommonDialog;
-import com.clustercontrol.dialog.ScopeTreeDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.repository.action.GetNodeProperty;
-import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.repository.bean.NodeConstant;
 import com.clustercontrol.repository.util.NodePropertyUtil;
 import com.clustercontrol.repository.util.RepositoryEndpointWrapper;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 import com.clustercontrol.ws.repository.FacilityDuplicate_Exception;
-import com.clustercontrol.ws.repository.FacilityTreeItem;
 import com.clustercontrol.ws.repository.InvalidRole_Exception;
 import com.clustercontrol.ws.repository.NodeInfo;
-import com.clustercontrol.repository.FacilityPath;
 
 /**
  * ノードの作成・変更ダイアログクラス<BR>
@@ -95,26 +90,14 @@ public class NodeCreateDialog extends CommonDialog {
 	/** 変更前のプロパティ */
 	private Property propertyOld = null;
 
+	/** 変更前のノード情報 */
+	private NodeInfo nodeInfoOld = null;
+
 	/** 変更用ダイアログ判別フラグ */
 	private boolean isModifyDialog = false;
 
-	/** 「登録方法の選択」でのノード指定フラグ */
-	private boolean isNodeSelected = true;
-
-	/** ノード単位選択ラジオボタン */
-	private Button radioCreateTypeNode = null;
-
-	/** スコープ単位選択ラジオボタン */
-	private Button radioCreateTypeScope = null;
-
-	/** スコープ文字列表示テキスト */
-	private Text textScope = null;
-
-	/** スコープ指定ダイアログ表示ボタン */
-	private Button buttonScope = null;
-
 	/** ノード属性プロパティシート */
-	protected PropertySheet propertySheet = null;
+	private PropertySheet propertySheet = null;
 
 	/** クリア実行フラグ */
 	private boolean isClearDone = false;
@@ -122,6 +105,9 @@ public class NodeCreateDialog extends CommonDialog {
 	/** クリアボタン */
 	private Button clearButtonScope = null;
 
+	/** オーナーロールID用テキスト */
+	private RoleIdListComposite m_ownerRoleId = null;
+
 	//SNMPで検出する機能のための追加コンポーネント
 	private Button buttonAuto = null;
 
@@ -136,7 +122,7 @@ public class NodeCreateDialog extends CommonDialog {
 	private TableTree table = null;
 
 	private NodeInfo nodeInfo = null;
-	
+
 	// ----- コンストラクタ ----- //
 
 	/**
@@ -188,37 +174,13 @@ public class NodeCreateDialog extends CommonDialog {
 		layout.marginHeight = 10;
 		parent.setLayout(layout);
 
-		// 登録方法の選択(グループ)
-		Group group = new Group(parent, SWT.SHADOW_NONE);
-		layout = new GridLayout(1, true);
-		group.setLayout(layout);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.horizontalSpan = 1;
-		group.setLayoutData(gridData);
-		group.setText(Messages.getString("registration.method"));
-
-		// ノード単位
-		this.radioCreateTypeNode = new Button(group, SWT.RADIO);
-		gridData = new GridData();
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		gridData.horizontalSpan = 1;
-		this.radioCreateTypeNode.setLayoutData(gridData);
-		this.radioCreateTypeNode.setText(Messages
-				.getString("registration.method.node.base"));
-
-
-		//SNMPで検索するためのコンポジット
-		Composite compositeSNMP = new Composite(group, SWT.NONE);
-		RowLayout rowLayoutAuto = new RowLayout();
-		rowLayoutAuto.marginLeft=20;
-		rowLayoutAuto.type = SWT.HORIZONTAL;
-		compositeSNMP.setLayout(rowLayoutAuto);
 
 		//SNMPによる検出のグループ(SNMP)
-		Group groupAuto = new Group(compositeSNMP, SWT.RIGHT);
+		Group groupAuto = new Group(parent, SWT.RIGHT);
 		layout = new GridLayout(5, false);
 		groupAuto.setLayout(layout);
 		if (isModifyDialog) {
@@ -234,19 +196,23 @@ public class NodeCreateDialog extends CommonDialog {
 
 		this.ipAddressBox = new Text(groupAuto, SWT.BORDER | SWT.SINGLE);
 		GridData grid = new GridData(GridData.FILL_HORIZONTAL);
-		grid.minimumWidth = 80;
+		grid.minimumWidth = 120;
 		this.ipAddressBox.setLayoutData(grid);
 
 		// プロパティ取得
 		if (this.isModifyDialog) {
-			propertyOld = new GetNodeProperty().getProperty(this.facilityId,
-					PropertyConstant.MODE_MODIFY);
+			GetNodeProperty getNodeProperty = new GetNodeProperty(this.facilityId,
+					PropertyDefineConstant.MODE_MODIFY);
+			propertyOld = getNodeProperty.getProperty();
+			nodeInfoOld = getNodeProperty.getNodeInfo();
 		} else {
-			propertyOld = new GetNodeProperty().getProperty(this.facilityId,
-					PropertyConstant.MODE_ADD);
+			GetNodeProperty getNodeProperty = new GetNodeProperty(this.facilityId,
+					PropertyDefineConstant.MODE_ADD);
+			propertyOld = getNodeProperty.getProperty();
+			nodeInfoOld = getNodeProperty.getNodeInfo();
 		}
 		Property propertyChild = null;
-		propertyChild = (Property)PropertyUtil.getProperty(propertyOld, NodeConstant.IP_ADDRESS_VERSION).get(0);
+		propertyChild = PropertyUtil.getProperty(propertyOld, NodeConstant.IP_ADDRESS_VERSION).get(0);
 		String ipAddressVersion = propertyChild.getValue().toString();
 		String ipAddress = null;
 		if ("6".equals(ipAddressVersion)) {
@@ -312,6 +278,15 @@ public class NodeCreateDialog extends CommonDialog {
 			this.versionBox.select(1);
 		}
 
+		// 変更時はFind By SNMPの項目はclearボタンが押下されない限り変更不可
+		if (isModifyDialog) {
+			this.ipAddressBox.setEditable(false);
+			this.portBox.setEditable(false);
+			this.communityBox.setEditable(false);
+			this.versionBox.setTouchEnabled(false);
+		}
+
+		
 		this.buttonAuto = new Button(groupAuto, SWT.PUSH | SWT.RIGHT);
 		this.buttonAuto.setText(" Find ");
 		gridData = new GridData();
@@ -319,7 +294,6 @@ public class NodeCreateDialog extends CommonDialog {
 		this.buttonAuto.setLayoutData(gridData);
 		this.buttonAuto.addSelectionListener(new SelectionAdapter() {
 			@Override
-			@SuppressWarnings("unchecked")
 			public void widgetSelected(SelectionEvent e) {
 				try{
 					String ipAddressString = ipAddressBox.getText();
@@ -349,21 +323,23 @@ public class NodeCreateDialog extends CommonDialog {
 
 
 					Property propertySNMP = null;
+					NodeInfo nodeInfo = null;
 
 					if (isModifyDialog) {
-						propertySNMP = GetNodePropertyBySNMP(ipAddress, port, community, version,
-								PropertyConstant.MODE_MODIFY);
+						nodeInfo = GetNodeInfoBySNMP(ipAddress, port, community, version,
+								PropertyDefineConstant.MODE_MODIFY);
+						propertySNMP = NodePropertyUtil.node2property(nodeInfo, PropertyDefineConstant.MODE_MODIFY, Locale.getDefault());
 						/*
 						 * ノード変更時のfind by snmpはデバイスのみ修正する。
 						 */
 						// 古い値を消して(device)
-						for(Object propertyObj : PropertyUtil.getProperty(propertyOld, NodeConstant.DEVICE)){
-							Property p = (Property)propertyObj;
+						for(Property propertyObj : PropertyUtil.getProperty(propertyOld, NodeConstant.DEVICE)){
+							Property p = propertyObj;
 							p.getParent().removeChildren(p);
 						}
 						// 新しい値を入れる(device)
-						for(Object propertyObj : PropertyUtil.getProperty(propertySNMP, NodeConstant.DEVICE)){
-							Property p = (Property)propertyObj;
+						for(Property propertyObj : PropertyUtil.getProperty(propertySNMP, NodeConstant.DEVICE)){
+							Property p = propertyObj;
 							propertyOld.addChildren(p);
 						}
 
@@ -399,21 +375,24 @@ public class NodeCreateDialog extends CommonDialog {
 							propertyOld.addChildren(p);
 
 							// 備考は複数含まれることがある。
-							ArrayList<Object> oArray = PropertyUtil.getProperty(propertyOld, NodeConstant.NOTE);
-							for (Object o : oArray) {
-								propertyOld.removeChildren((Property)o);
-								propertyOld.addChildren((Property)o);
+							ArrayList<Property> oArray = PropertyUtil.getProperty(propertyOld, NodeConstant.NOTE);
+							for (Property o : oArray) {
+								propertyOld.removeChildren(o);
+								propertyOld.addChildren(o);
 							}
 						}
 						propertySheet.setInput(propertyOld);
 					} else {
-						propertySNMP = GetNodePropertyBySNMP(ipAddress, port, community, version,
-								PropertyConstant.MODE_ADD);
+						nodeInfo = GetNodeInfoBySNMP(ipAddress, port, community, version,
+								PropertyDefineConstant.MODE_ADD);
+						propertySNMP = NodePropertyUtil.node2property(nodeInfo, PropertyDefineConstant.MODE_ADD, Locale.getDefault());
 						propertySheet.setInput(propertySNMP);
 					}
 
 					// シートの展開と色表示
 					update();
+					expand();
+					
 				} catch (NumberFormatException e1){
 					// port番号が不正な場合
 					MessageDialog.openWarning(getShell(), "Warning", Messages.getString("message.repository.38"));
@@ -425,98 +404,33 @@ public class NodeCreateDialog extends CommonDialog {
 			}
 		});
 
+		/////////////////////////////////////////////////////////////
 
-		// スコープ単位
-		this.radioCreateTypeScope = new Button(group, SWT.RADIO);
+		/*
+		 * オーナーロールID
+		 */
+		Label labelRoleId = new Label(parent, SWT.LEFT);
 		gridData = new GridData();
+		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		gridData.horizontalSpan = 1;
-		this.radioCreateTypeScope.setLayoutData(gridData);
-		this.radioCreateTypeScope.setText(Messages
-				.getString("registration.method.scope.base"));
-
-		// スコープ指定
-		Composite composite = new Composite(group, SWT.NONE);
-		RowLayout rowLayout = new RowLayout();
-		rowLayout.type = SWT.HORIZONTAL;
-		composite.setLayout(rowLayout);
+		labelRoleId.setLayoutData(gridData);
+		labelRoleId.setText(Messages.getString("owner.role.id") + " : ");
+		if(!this.isModifyDialog()){
+			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, true, Mode.OWNER_ROLE);
+		} else {
+			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, false, Mode.OWNER_ROLE);
+		}
+		if (nodeInfoOld != null && nodeInfoOld.getOwnerRoleId() != null) {
+			m_ownerRoleId.setText(nodeInfoOld.getOwnerRoleId());
+		}
 		gridData = new GridData();
+		gridData.horizontalSpan = 1;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
-		gridData.horizontalSpan = 1;
-		composite.setLayoutData(gridData);
-		// ダミーラベル
-		Label dummy = new Label(composite, SWT.NONE);
-		dummy.setLayoutData(new RowData(12, SizeConstant.SIZE_LABEL_HEIGHT));
-		// スコープ文字列テキスト
-		this.textScope = new Text(composite, SWT.BORDER | SWT.LEFT
-				| SWT.READ_ONLY);
-		this.textScope.setText("");
-		this.textScope.setLayoutData(new RowData(300,
-				SizeConstant.SIZE_TEXT_HEIGHT));
-		this.buttonScope = new Button(composite, SWT.PUSH);
-		this.buttonScope.setText(Messages.getString("refer"));
-		this.buttonScope.pack();
-		if (!this.isModifyDialog) {
-			this.buttonScope.setEnabled(false);
-		}
-		this.buttonScope.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				ScopeTreeDialog dialog = new ScopeTreeDialog(getParentShell(),
-						true);
-				if (dialog.open() == IDialogConstants.OK_ID) {
-					FacilityTreeItem selectItem = dialog.getSelectItem();
-					if (selectItem.getData().getFacilityType() == FacilityConstant.TYPE_COMPOSITE) {
-						textScope.setText("");
-						scopeId = "";
-					} else {
-						FacilityPath facilityPath = new FacilityPath(
-								ClusterControlPlugin.getDefault()
-								.getSeparator());
-						textScope.setText(facilityPath.getPath(selectItem));
-						scopeId = selectItem.getData().getFacilityId();
-					}
-				}
-			}
-		}
-
-		);
-
-		// ディフォルトではノード単位を選択
-		this.radioCreateTypeNode.setSelection(true);
-		this.textScope.setEnabled(false);
-		this.buttonScope.setEnabled(false);
-
-		// ラジオボタンのイベント
-		this.radioCreateTypeNode.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				textScope.setEnabled(false);
-				buttonScope.setEnabled(false);
-				clearButtonScope.setEnabled(false);
-
-				NodePropertyUtil.modifyPropertySetting((Property)propertySheet.getInput(), true);
-			}
-		});
-		this.radioCreateTypeScope.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				textScope.setEnabled(true);
-				buttonScope.setEnabled(true);
-				clearButtonScope.setEnabled(true);
-
-				NodePropertyUtil.modifyPropertySetting((Property)propertySheet.getInput(), false);
-			}
-		});
-
-		// 登録処理の場合、スコープ関連は使用不可とする。
-		if (!this.isModifyDialog) {
-			this.radioCreateTypeScope.setEnabled(false);
-			this.clearButtonScope.setEnabled(false);
-		}
-
+		m_ownerRoleId.setLayoutData(gridData);
+		
+		
 		/*
 		 * 属性プロパティシート
 		 */
@@ -538,6 +452,7 @@ public class NodeCreateDialog extends CommonDialog {
 		gridData.verticalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.grabExcessVerticalSpace = true;
+		gridData.heightHint = SWT.MIN;
 		gridData.horizontalSpan = 1;
 		table.setLayoutData(gridData);
 		table.addSelectionListener(new SelectionAdapter(){
@@ -549,12 +464,11 @@ public class NodeCreateDialog extends CommonDialog {
 		});
 
 		this.propertySheet = new PropertySheet(table);
+		this.propertySheet.setSize(230, 300);
 
 		// プロパティ設定
 		this.propertySheet.setInput(propertyOld);
 
-		/////////////////////////////////////////////////////////////
-
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
 		gridData = new GridData();
@@ -573,156 +487,114 @@ public class NodeCreateDialog extends CommonDialog {
 		shell.setSize(new Point(shell.getSize().x, sizeY ));
 
 		this.update();
-
+		this.expand();
 	}
 
 	/**
-	 * 更新処理
+	 * プロパティシートの展開
 	 * 
 	 */
-	public void update(){
-
+	private void expand(){
+		
+		m_log.debug("expand");
 		/*プロパティシートの展開を指定します。*/
-
 		//レベル1までの展開
 		this.propertySheet.expandToLevel(1);
 		//サーバ基本情報
 		Object element =  this.propertySheet.getElementAt(4);
 		this.propertySheet.expandToLevel(element, 2);
 		//サービス
-		element =  this.propertySheet.getElementAt(5);
-		this.propertySheet.expandToLevel(element, 1);
-		//デバイス
 		element =  this.propertySheet.getElementAt(6);
 		this.propertySheet.expandToLevel(element, 1);
+		//デバイス
+		element =  this.propertySheet.getElementAt(7);
+		this.propertySheet.expandToLevel(element, 1);
+	}
+	
+	/**
+	 * 更新処理
+	 * 
+	 */
+	public void update(){
 
+		m_log.debug("update");
 
 		/*必須項目を色別表示します。*/
 
 		// ファシリティIDのインデックス：0
-		if("".equals(table.getItem(0).getText(1))){
-			table.getItem(0).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-		}else{
-			table.getItem(0).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-		}
+		setColor(table.getItem(0));
 
 		// ファシリティ名のインデックス：1
-		if("".equals(table.getItem(1).getText(1))){
-			table.getItem(1).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-		}else{
-			table.getItem(1).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-		}
+		setColor(table.getItem(1));
 
 		// プラットフォームのインデックス：4-0-1
-		if("".equals(table.getItem(4).getItem(0).getItem(0).getText(1))){
-			table.getItem(4).getItem(0).getItem(0).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-		}else{
-			table.getItem(4).getItem(0).getItem(0).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		if(table.getItem(4).getItemCount() > 0 && table.getItem(4).getItem(0).getItemCount() > 0) {
+			setColor(table.getItem(4).getItem(0).getItem(0));
 		}
 
 		// ネットワークのインデックス：4-1
-		if("4".equals((table.getItem(4).getItem(1).getItem(0).getText(1)))){
-			// -IPv4のアドレスのインデックス：5
-			if("".equals(table.getItem(4).getItem(1).getItem(1).getText(1))){
-				table.getItem(4).getItem(1).getItem(1).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		if (table.getItem(4).getItemCount() > 1 && table.getItem(4).getItem(1).getItemCount() > 0) {
+			if("4".equals((table.getItem(4).getItem(1).getItem(0).getText(1)))){
+				table.getItem(4).getItem(1).getItem(0).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				setColor(table.getItem(4).getItem(1).getItem(1));
 				table.getItem(4).getItem(1).getItem(2).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			}else{
+			}else if("6".equals((table.getItem(4).getItem(1).getItem(0).getText(1)))){
+				table.getItem(4).getItem(1).getItem(0).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				table.getItem(4).getItem(1).getItem(1).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				setColor(table.getItem(4).getItem(1).getItem(2));
+			}else {
+				table.getItem(4).getItem(1).getItem(0).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
 				table.getItem(4).getItem(1).getItem(1).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 				table.getItem(4).getItem(1).getItem(2).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 			}
-		}else if("6".equals((table.getItem(4).getItem(1).getItem(0).getText(1)))){
-			// -IPv6のアドレスのインデックス：6
-			if("".equals(table.getItem(4).getItem(1).getItem(2).getText(1))){
-				table.getItem(4).getItem(1).getItem(2).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-				table.getItem(4).getItem(1).getItem(1).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			}else{
-				table.getItem(4).getItem(1).getItem(2).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-				table.getItem(4).getItem(1).getItem(1).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			}
 		}
 
-		// OSのインデックス：8
-		// -ノード名のインデックス:0
-		if("".equals(table.getItem(4).getItem(2).getItem(0).getText(1))){
-			table.getItem(4).getItem(2).getItem(0).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-		}else{
-			table.getItem(4).getItem(2).getItem(0).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		// OSのインデックス:4
+		// -ノード名のインデックス:2
+		if (table.getItem(4).getItemCount() > 2 && table.getItem(4).getItem(2).getItemCount() > 0) {
+			setColor(table.getItem(4).getItem(2).getItem(0));
 		}
-
-		// 仮想化のインデックス:7
+		
+		// 仮想化のインデックス:8
 		// -ノード種別のインデックス:0
-		if("controller".equals(table.getItem(7).getItem(0).getText(1)) || "host".equals(table.getItem(7).getItem(0).getText(1))){
-			// ノード種別が"guest"だった場合の色をクリア
-			table.getItem(7).getItem(4).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			table.getItem(7).getItem(1).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			table.getItem(7).getItem(3).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			table.getItem(7).getItem(5).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-
-			// -仮想化ソリューションのインデックス:4
-			if("".equals(table.getItem(7).getItem(4).getText(1))){
-				table.getItem(7).getItem(4).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-			}else{
-				table.getItem(7).getItem(4).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		if (table.getItem(8).getItemCount() > 6) {
+			if("controller".equals(table.getItem(8).getItem(0).getText(1)) || "host".equals(table.getItem(8).getItem(0).getText(1))){
+				table.getItem(8).getItem(1).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				table.getItem(8).getItem(2).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				table.getItem(8).getItem(3).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				setColor(table.getItem(8).getItem(4));
+				setColor(table.getItem(8).getItem(5));
+				setColor(table.getItem(8).getItem(6));
+			}else if("guest".equals(table.getItem(8).getItem(0).getText(1))){
+				setColor(table.getItem(8).getItem(1));
+				setColor(table.getItem(8).getItem(2));
+				setColor(table.getItem(8).getItem(3));
+				table.getItem(8).getItem(4).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				table.getItem(8).getItem(5).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				table.getItem(8).getItem(6).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}else {
+				// 仮想化のツリーを開いており、ノード種別が空欄の場合
+				table.getItem(8).getItem(1).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				table.getItem(8).getItem(3).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				table.getItem(8).getItem(2).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				table.getItem(8).getItem(4).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				table.getItem(8).getItem(5).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+				table.getItem(8).getItem(6).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 			}
-			// -仮想化ソフト接続ユーザのインデックス:6
-			if("".equals(table.getItem(7).getItem(6).getText(1))){
-				table.getItem(7).getItem(6).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-			}else{
-				table.getItem(7).getItem(6).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			}
-			// -仮想化ソフト接続ユーザパスワードのインデックス:7
-			if("".equals(table.getItem(7).getItem(7).getText(1))){
-				table.getItem(7).getItem(7).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-			}else{
-				table.getItem(7).getItem(7).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			}
-			// -仮想化ソフト接続プロトコルのインデックス:8
-			if("".equals(table.getItem(7).getItem(8).getText(1))){
-				table.getItem(7).getItem(8).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-			}else{
-				table.getItem(7).getItem(8).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			}
-		}else if("guest".equals(table.getItem(7).getItem(0).getText(1))){
-			// ノード種別が"host"または"controller"だった場合の色をクリア
-			table.getItem(7).getItem(4).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			table.getItem(7).getItem(6).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			table.getItem(7).getItem(7).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			table.getItem(7).getItem(8).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-
-			// -仮想化ソリューションのインデックス:4
-			if("".equals(table.getItem(7).getItem(4).getText(1))){
-				table.getItem(7).getItem(4).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-			}else{
-				table.getItem(7).getItem(4).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			}
-			// -管理ノードのインデックス:1
-			if("".equals(table.getItem(7).getItem(1).getText(1))){
-				table.getItem(7).getItem(1).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-			}else{
-				table.getItem(7).getItem(1).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			}
-			// -仮想マシン名のインデックス:3
-			if("".equals(table.getItem(7).getItem(3).getText(1))){
-				table.getItem(7).getItem(3).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-			}else{
-				table.getItem(7).getItem(3).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			}
-			// -仮想マシンIDのインデックス:5
-			if("".equals(table.getItem(7).getItem(5).getText(1))){
-				table.getItem(7).getItem(5).setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-			}else{
-				table.getItem(7).getItem(5).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			}
-		}else if(table.getItem(7).getItemCount() > 1){
-			// 仮想化のツリーを開いており、ノード種別が空欄の場合
-			table.getItem(7).getItem(1).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			table.getItem(7).getItem(3).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			table.getItem(7).getItem(4).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			table.getItem(7).getItem(5).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			table.getItem(7).getItem(6).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			table.getItem(7).getItem(7).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-			table.getItem(7).getItem(8).setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-		}	}
+		}
+	}
+	
+	/**
+	 * 空文字だったらピンク色にする。
+	 * @param item
+	 */
+	private void setColor(TableTreeItem item) {
+		if ("".equals(item.getText(1))) {
+			item.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+		} else {
+			item.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		}
+	}
 
 	/**
 	 * 既存のボタンに加え、クリアボタンを追加します。
@@ -734,33 +606,44 @@ public class NodeCreateDialog extends CommonDialog {
 	protected void createButtonsForButtonBar(Composite parent) {
 		// クリアボタン
 		clearButtonScope =
-			this.createButton(parent, IDialogConstants.OPEN_ID, Messages
-					.getString("clear"), false);
+				this.createButton(parent, IDialogConstants.OPEN_ID, Messages
+						.getString("clear"), false);
 		this.getButton(IDialogConstants.OPEN_ID).addSelectionListener(
 				new SelectionAdapter() {
 					@Override
 					public void widgetSelected(SelectionEvent e) {
 						// プロパティ取得及び設定
 						Property property = null;
+						NodeInfo nodeInfo = null;
 						if (isModifyDialog()) {
-							property = new GetNodeProperty().getProperty(null,
-									PropertyConstant.MODE_MODIFY);
+							GetNodeProperty getNodeProperty = new GetNodeProperty(null,
+									PropertyDefineConstant.MODE_MODIFY);
+							property = getNodeProperty.getProperty();
+							nodeInfo = getNodeProperty.getNodeInfo();
 
 							//ファシリティID設定
-							ArrayList list = PropertyUtil.getProperty(property,
+							ArrayList<Property> list = PropertyUtil.getProperty(property,
 									NodeConstant.FACILITY_ID);
-							((Property) list.get(0)).setValue(getFacilityId());
+							list.get(0).setValue(getFacilityId());
 						} else {
-							property = new GetNodeProperty().getProperty(null,
-									PropertyConstant.MODE_ADD);
+							GetNodeProperty getNodeProperty = new GetNodeProperty(null,
+									PropertyDefineConstant.MODE_ADD);
+							property = getNodeProperty.getProperty();
+							nodeInfo = getNodeProperty.getNodeInfo();
 						}
 
 						//Booleanエディタのプロパティにnullを設定する
 						PropertyUtil.setPropertyValue(property,
-								PropertyConstant.EDITOR_BOOL, null);
+								PropertyDefineConstant.EDITOR_BOOL, null);
 
 						setInputData(property);
 
+						// 変更モードの場合にclearボタン契機でFind By SNMPの変更を可能にする
+						ipAddressBox.setEditable(true);
+						portBox.setEditable(true);
+						communityBox.setEditable(true);
+						versionBox.setTouchEnabled(true);
+						
 						// クリア実行フラグ
 						isClearDone = true;
 					}
@@ -801,10 +684,13 @@ public class NodeCreateDialog extends CommonDialog {
 				PropertyUtil.deletePropertyDefine(copy);
 				try {
 					nodeInfo = NodePropertyUtil.property2node(copy);
+					if (m_ownerRoleId.getText().length() > 0) {
+						nodeInfo.setOwnerRoleId(m_ownerRoleId.getText());
+					}
 					RepositoryEndpointWrapper.addNode(nodeInfo);
 
 					// リポジトリキャッシュの更新
-					FacilityTree.reflesh();
+					LocalSession.doCheck();
 
 					MessageDialog.openInformation(
 							null,
@@ -842,91 +728,40 @@ public class NodeCreateDialog extends CommonDialog {
 				}
 			} else {
 				// 変更の場合
-				if (this.isNodeSelected()) {
-					Property copy = PropertyUtil.copy(property);
-					PropertyUtil.deletePropertyDefine(copy);
-					try {
-						nodeInfo = NodePropertyUtil.property2node(copy);
-						RepositoryEndpointWrapper.modifyNode(nodeInfo);
+				Property copy = PropertyUtil.copy(property);
+				PropertyUtil.deletePropertyDefine(copy);
+				try {
+					nodeInfo = NodePropertyUtil.property2node(copy);
+					if (m_ownerRoleId.getText().length() > 0) {
+						nodeInfo.setOwnerRoleId(m_ownerRoleId.getText());
+					}
+					RepositoryEndpointWrapper.modifyNode(nodeInfo);
 
-						// リポジトリキャッシュの更新
-						FacilityTree.reflesh();
+					// リポジトリキャッシュの更新
+					LocalSession.doCheck();
 
+					MessageDialog.openInformation(
+							null,
+							Messages.getString("successful"),
+							Messages.getString("message.repository.10"));
+
+					result = true;
+
+				} catch (Exception e) {
+					if (e instanceof InvalidRole_Exception) {
+						// アクセス権なしの場合、エラーダイアログを表示する
 						MessageDialog.openInformation(
 								null,
-								Messages.getString("successful"),
-								Messages.getString("message.repository.10"));
-
-						result = true;
-
-					} catch (Exception e) {
-						if (e instanceof InvalidRole_Exception) {
-							// アクセス権なしの場合、エラーダイアログを表示する
-							MessageDialog.openInformation(
-									null,
-									Messages.getString("message"),
-									Messages.getString("message.accesscontrol.16"));
-						} else {
-							errMessage = ", " + e.getMessage();
-						}
-
-						MessageDialog.openError(
-								null,
-								Messages.getString("failed"),
-								Messages.getString("message.repository.11") + errMessage);
+								Messages.getString("message"),
+								Messages.getString("message.accesscontrol.16"));
+					} else {
+						errMessage = ", " + e.getMessage();
 					}
 
-				} else {
-					boolean done = false;
-					if(this.isClearDone()){
-						// クリアボタンがクリックされていた場合、更新処理を行う。
-						done = true;
-					}
-					else{
-						// 確認ダイアログにてOKが選択された場合、更新処理を行う。
-						if (MessageDialog.openConfirm(
-								null,
-								Messages.getString("confirmed"),
-								Messages.getString("message.repository.20"))) {
-							done = true;
-						}
-					}
-
-					if(done){
-						// スコープ単位で更新
-						Property copy = PropertyUtil.copy(property);
-						PropertyUtil.deletePropertyDefine(copy);
-						try {
-							nodeInfo = NodePropertyUtil.property2node(copy);
-							RepositoryEndpointWrapper.modifyAllNode(nodeInfo, this.getScopeId());
-
-							// リポジトリキャッシュの更新
-							FacilityTree.reflesh();
-
-							MessageDialog.openInformation(
-									null,
-									Messages.getString("successful"),
-									Messages.getString("message.repository.10"));
-
-							result = true;
-
-						} catch (Exception e) {
-							if (e instanceof InvalidRole_Exception) {
-								// アクセス権なしの場合、エラーダイアログを表示する
-								MessageDialog.openInformation(
-										null,
-										Messages.getString("message"),
-										Messages.getString("message.accesscontrol.16"));
-							} else {
-								errMessage = ", " + e.getMessage();
-							}
-
-							MessageDialog.openError(
-									null,
-									Messages.getString("failed"),
-									Messages.getString("message.repository.11") + errMessage);
-						}
-					}
+					MessageDialog.openError(
+							null,
+							Messages.getString("failed"),
+							Messages.getString("message.repository.11") + errMessage);
 				}
 			}
 		}
@@ -943,15 +778,6 @@ public class NodeCreateDialog extends CommonDialog {
 		return this.isModifyDialog;
 	}
 
-	/**
-	 * 「登録方法の選択」にて、ノード単位が選択されているかを返します。
-	 * 
-	 * @return ノード単位が選択されている場合、true
-	 */
-	public boolean isNodeSelected() {
-		return this.isNodeSelected;
-	}
-
 	/**
 	 * 一括変更対象スコープのファシリティIDを返します。
 	 * 
@@ -1028,7 +854,7 @@ public class NodeCreateDialog extends CommonDialog {
 	public NodeInfo getNodeInfo() {
 		return this.nodeInfo;
 	}
-	
+
 	/**
 	 *SNMPを利用してノード情報を生成します。<BR>
 	 *
@@ -1036,14 +862,13 @@ public class NodeCreateDialog extends CommonDialog {
 	 * @param mode 編集可否モード
 	 * @return ノード情報のプロパティ
 	 */
-	private static Property GetNodePropertyBySNMP(String ipAddress, int port, String community, String version,int mode) {
+	private static NodeInfo GetNodeInfoBySNMP(String ipAddress, int port, String community, String version,int mode) {
 
 		try {
 			NodeInfo nodeInfo = RepositoryEndpointWrapper.getNodePropertyBySNMP(ipAddress, port, community, version);
 			m_log.info("snmp2 " + nodeInfo.getNodeFilesystemInfo().size());
 			NodePropertyUtil.setDefaultNode(nodeInfo);
-			m_log.info("snmp3 " + nodeInfo.getNodeFilesystemInfo().size());
-			return NodePropertyUtil.node2property(nodeInfo, mode, Locale.getDefault());
+			return nodeInfo;
 		} catch (InvalidRole_Exception e) {
 			MessageDialog.openInformation(null, Messages.getString("message"),
 					Messages.getString("message.accesscontrol.16"));
@@ -1056,4 +881,5 @@ public class NodeCreateDialog extends CommonDialog {
 		}
 		return null;
 	}
+
 }
\ No newline at end of file
