@@ -9,7 +9,7 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.bean.PropertyConstant;
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.repository.bean.ScopeConstant;
 import com.clustercontrol.util.Messages;
@@ -46,13 +46,16 @@ public class ScopePropertyUtil {
 
 		object1 = PropertyUtil.getPropertyValue(property, ScopeConstant.DESCRIPTION);
 		scopeInfo.setDescription((String)object1.get(0));
+		
+		object1 = PropertyUtil.getPropertyValue(property,ScopeConstant.ICONIMAGE);
+		scopeInfo.setIconImage((String)object1.get(0));
 
 		return scopeInfo;
 	}
 
 	public static Property scope2property (ScopeInfo scopeInfo, int mode, Locale locale) {
 		Property property = null;
-		ArrayList propertyList = null;
+		ArrayList<Property> propertyList = null;
 
 		property = getProperty(mode, locale);
 
@@ -65,6 +68,9 @@ public class ScopePropertyUtil {
 		propertyList = PropertyUtil.getProperty(property, ScopeConstant.DESCRIPTION);
 		((Property)propertyList.get(0)).setValue(scopeInfo.getDescription());
 
+		propertyList = PropertyUtil.getProperty(property, ScopeConstant.ICONIMAGE);
+		((Property)propertyList.get(0)).setValue(scopeInfo.getIconImage());
+		
 		return property;
 	}
 
@@ -90,28 +96,34 @@ public class ScopePropertyUtil {
 
 		//ファシリティID
 		Property facilityId =
-			new Property(ScopeConstant.FACILITY_ID, Messages.getString("facility.id", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+				new Property(ScopeConstant.FACILITY_ID, Messages.getString("facility.id", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
 		//ファシリティ名
 		Property facilityName =
-			new Property(ScopeConstant.FACILITY_NAME, Messages.getString("facility.name", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_256);
+				new Property(ScopeConstant.FACILITY_NAME, Messages.getString("facility.name", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_256);
 		//説明
 		Property description =
-			new Property(ScopeConstant.DESCRIPTION, Messages.getString("description", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+				new Property(ScopeConstant.DESCRIPTION, Messages.getString("description", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+		//アイコン
+		Property iconIname = 
+				new Property(ScopeConstant.ICONIMAGE, Messages.getString("icon.image", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
 
 		//値を初期化
 		facilityId.setValue("");
 		facilityName.setValue("");
 		description.setValue("");
+		iconIname.setValue("");
 
 		//モードにより、変更を可に設定
-		if(mode == PropertyConstant.MODE_ADD){
-			facilityId.setModify(PropertyConstant.MODIFY_OK);
-			facilityName.setModify(PropertyConstant.MODIFY_OK);
-			description.setModify(PropertyConstant.MODIFY_OK);
+		if(mode == PropertyDefineConstant.MODE_ADD){
+			facilityId.setModify(PropertyDefineConstant.MODIFY_OK);
+			facilityName.setModify(PropertyDefineConstant.MODIFY_OK);
+			description.setModify(PropertyDefineConstant.MODIFY_OK);
+			iconIname.setModify(PropertyDefineConstant.MODIFY_OK);
 		}
-		else if(mode == PropertyConstant.MODE_MODIFY){
-			facilityName.setModify(PropertyConstant.MODIFY_OK);
-			description.setModify(PropertyConstant.MODIFY_OK);
+		else if(mode == PropertyDefineConstant.MODE_MODIFY){
+			facilityName.setModify(PropertyDefineConstant.MODIFY_OK);
+			description.setModify(PropertyDefineConstant.MODIFY_OK);
+			iconIname.setModify(PropertyDefineConstant.MODIFY_OK);
 		}
 
 		Property property = new Property(null, null, "");
@@ -120,6 +132,7 @@ public class ScopePropertyUtil {
 		property.addChildren(facilityId);
 		property.addChildren(facilityName);
 		property.addChildren(description);
+		property.addChildren(iconIname);
 
 		// 初期値をキャッシュに登録（次回から高速化に初期値を取得）
 		m_log.info("adding a initial property of scope to cache. (locale = " + locale + ", mode = " + mode + ")");
