@@ -20,6 +20,7 @@ import org.eclipse.jface.action.IMenuListener;
 import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
+import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.GridData;
@@ -31,8 +32,10 @@ import com.clustercontrol.bean.Property;
 import com.clustercontrol.repository.composite.NodeListComposite;
 import com.clustercontrol.repository.composite.action.NodeListSelectionChangedListener;
 import com.clustercontrol.repository.view.action.NodeAddAction;
+import com.clustercontrol.repository.view.action.NodeCopyAction;
 import com.clustercontrol.repository.view.action.NodeDeleteAction;
 import com.clustercontrol.repository.view.action.NodeModifyAction;
+import com.clustercontrol.repository.view.action.ProgramExecutionAction;
 import com.clustercontrol.view.CommonViewPart;
 
 /**
@@ -96,7 +99,7 @@ public class NodeListView extends CommonViewPart {
 	 * 
 	 * 
 	 */
-	protected void createContextMenu() {
+	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
 		menuManager.addMenuListener(new IMenuListener() {
@@ -121,21 +124,28 @@ public class NodeListView extends CommonViewPart {
 	 * 
 	 * @param manager
 	 */
-	protected void fillContextMenu(IMenuManager manager) {
+	private void fillContextMenu(IMenuManager manager) {
 		//ビューのアクションのインスタンスを取得
 		IToolBarManager toolbar = this.getViewSite().getActionBars()
-		.getToolBarManager();
+				.getToolBarManager();
 		ActionContributionItem nodeAddAction = (ActionContributionItem) toolbar
-		.find(NodeAddAction.ID);
+				.find(NodeAddAction.ID);
 		ActionContributionItem nodeModifyAction = (ActionContributionItem) toolbar
-		.find(NodeModifyAction.ID);
+				.find(NodeModifyAction.ID);
 		ActionContributionItem nodeDeleteAction = (ActionContributionItem) toolbar
-		.find(NodeDeleteAction.ID);
+				.find(NodeDeleteAction.ID);
+		ActionContributionItem nodeCopyAction = (ActionContributionItem) toolbar
+				.find(NodeCopyAction.ID);
+		ActionContributionItem programExecutionAction = (ActionContributionItem) toolbar
+				.find(ProgramExecutionAction.ID);
 
 		//ポップアップメニューにアクションを追加
 		manager.add(nodeAddAction.getAction());
 		manager.add(nodeModifyAction.getAction());
 		manager.add(nodeDeleteAction.getAction());
+		manager.add(new Separator());
+		manager.add(nodeCopyAction.getAction());
+		manager.add(programExecutionAction.getAction());
 	}
 
 	/**
@@ -181,15 +191,21 @@ public class NodeListView extends CommonViewPart {
 	 */
 	public void setEnabledAction(int num, ISelection selection) {
 		//ビューアクションの使用可/不可を設定
+		super.setEnabledAction(NodeCopyAction.ID, selection);
 		super.setEnabledAction(NodeDeleteAction.ID, selection);
 		super.setEnabledAction(NodeModifyAction.ID, selection);
+		super.setEnabledAction(ProgramExecutionAction.ID, selection);
 
 		if (num > 0){
+			super.setEnabledAction(NodeCopyAction.ID, true);
 			super.setEnabledAction(NodeDeleteAction.ID, true);
 			super.setEnabledAction(NodeModifyAction.ID, true);
+			super.setEnabledAction(ProgramExecutionAction.ID, true);
 		} else {
+			super.setEnabledAction(NodeCopyAction.ID, false);
 			super.setEnabledAction(NodeDeleteAction.ID, false);
 			super.setEnabledAction(NodeModifyAction.ID, false);
+			super.setEnabledAction(ProgramExecutionAction.ID, false);
 		}
 	}
 }
\ No newline at end of file
