@@ -29,12 +29,12 @@ import org.eclipse.swt.widgets.Shell;
 
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.Property;
-import com.clustercontrol.composite.PropertySheet;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.snmptrap.action.GetSnmpTrapModifyProperty;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
+import com.clustercontrol.viewer.PropertySheet;
 import com.clustercontrol.ws.monitor.MonitorTrapValueInfo;
 
 /**
@@ -45,7 +45,7 @@ import com.clustercontrol.ws.monitor.MonitorTrapValueInfo;
  */
 public class SnmpTrapModifyDialog extends CommonDialog {
 	/** プロパティシート */
-	protected PropertySheet viewer = null;
+	private PropertySheet viewer = null;
 
 	private Shell shell = null;
 
@@ -131,65 +131,63 @@ public class SnmpTrapModifyDialog extends CommonDialog {
 			property = new GetSnmpTrapModifyProperty().getProperty();
 
 			//MIB
-			ArrayList propertyList =
-				PropertyUtil.getProperty(
-						property, GetSnmpTrapModifyProperty.ID_MIB);
+			ArrayList<Property> propertyList = PropertyUtil.getProperty(property, GetSnmpTrapModifyProperty.ID_MIB);
 			Property mib = (Property) propertyList.get(0);
 			mib.setValue(oidInfo.getMib());
 
 			//トラップ名
 			propertyList =
-				PropertyUtil.getProperty(
-						property, GetSnmpTrapModifyProperty.ID_TRAP_NAME);
+					PropertyUtil.getProperty(
+							property, GetSnmpTrapModifyProperty.ID_TRAP_NAME);
 			Property trapName = (Property) propertyList.get(0);
 			trapName.setValue(oidInfo.getUei());
 
 			//トラップOID
 			propertyList =
-				PropertyUtil.getProperty(
-						property, GetSnmpTrapModifyProperty.ID_TRAP_OID);
+					PropertyUtil.getProperty(
+							property, GetSnmpTrapModifyProperty.ID_TRAP_OID);
 			Property trapOid = (Property) propertyList.get(0);
 			trapOid.setValue(oidInfo.getTrapOid());
 
 			//generic_id
 			propertyList =
-				PropertyUtil.getProperty(
-						property, GetSnmpTrapModifyProperty.ID_GENERIC_ID);
+					PropertyUtil.getProperty(
+							property, GetSnmpTrapModifyProperty.ID_GENERIC_ID);
 			Property genericId = (Property) propertyList.get(0);
 			genericId.setValue(Integer.toString(oidInfo.getGenericId()));
 
 			//specific_id
 			propertyList =
-				PropertyUtil.getProperty(
-						property, GetSnmpTrapModifyProperty.ID_SPRCIFIC_ID);
+					PropertyUtil.getProperty(
+							property, GetSnmpTrapModifyProperty.ID_SPRCIFIC_ID);
 			Property specificId = (Property) propertyList.get(0);
 			specificId.setValue(Integer.toString(oidInfo.getSpecificId()));
 
 			//有効無効
 			propertyList =
-				PropertyUtil.getProperty(
-						property, GetSnmpTrapModifyProperty.ID_VALID);
+					PropertyUtil.getProperty(
+							property, GetSnmpTrapModifyProperty.ID_VALID);
 			Property valid = (Property) propertyList.get(0);
 			valid.setValue(new Boolean(oidInfo.isValidFlg()));
 
 			//重要度
 			propertyList =
-				PropertyUtil.getProperty(
-						property, GetSnmpTrapModifyProperty.ID_PRIORITY);
+					PropertyUtil.getProperty(
+							property, GetSnmpTrapModifyProperty.ID_PRIORITY);
 			Property priority = (Property) propertyList.get(0);
 			priority.setValue(PriorityConstant.typeToString(oidInfo.getPriority()));
 
 			//メッセージ
 			propertyList =
-				PropertyUtil.getProperty(
-						property, GetSnmpTrapModifyProperty.ID_LOGMSG);
+					PropertyUtil.getProperty(
+							property, GetSnmpTrapModifyProperty.ID_LOGMSG);
 			Property logmsg = (Property) propertyList.get(0);
 			logmsg.setValue(oidInfo.getLogmsg());
 
 			//詳細メッセージ
 			propertyList =
-				PropertyUtil.getProperty(
-						property, GetSnmpTrapModifyProperty.ID_DESCR);
+					PropertyUtil.getProperty(
+							property, GetSnmpTrapModifyProperty.ID_DESCR);
 			Property descr = (Property) propertyList.get(0);
 			descr.setValue(oidInfo.getDescr());
 
